
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
IBAN module of the Python FinTech package.

This module defines functions to check and create IBANs.
"""

__all__ = ['check_iban', 'create_iban', 'check_bic', 'get_bic', 'parse_iban', 'get_bankname']

def check_iban(iban, bic=None, country=None, sepa=False):
    """
    Checks an IBAN for validity.

    If the *kontocheck* package is available, for German IBANs the
    bank code and the checksum of the account number are checked as
    well.

    :param iban: The IBAN to be checked.
    :param bic: If given, IBAN and BIC are checked in the
        context of each other.
    :param country: If given, the IBAN is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param sepa: If *sepa* evaluates to ``True``, the IBAN is
        checked to be valid in the Single Euro Payments Area.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    ...


def create_iban(bankcode, account, bic=False):
    """
    Creates an IBAN from a German bank code and account number.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.

    :param bankcode: The German bank code.
    :param account: The account number.
    :param bic: Flag if the corresponding BIC should be returned as well.
    :returns: Either the IBAN or a 2-tuple in the form of (IBAN, BIC).
    """
    ...


def check_bic(bic, country=None, scl=False):
    """
    Checks a BIC for validity.

    :param bic: The BIC to be checked.
    :param country: If given, the BIC is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param scl: If set to ``True``, the BIC is checked for occurrence
        in the SEPA Clearing Directory, published by the German Central
        Bank. If set to a value of *SCT*, *SDD*, *COR1*, or *B2B*, *SCC*,
        the BIC is also checked to be valid for this payment order type.
        The *kontocheck* package is required for this option.
        Otherwise a *RuntimeError* is raised.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    ...


def get_bic(iban):
    """
    Returns the corresponding BIC for a given German IBAN.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    ...


def parse_iban(iban):
    """
    Splits a given IBAN into its fragments.

    Returns a 4-tuple in the form of
    (COUNTRY, CHECKSUM, BANK_CODE, ACCOUNT_NUMBER)
    """
    ...


def get_bankname(iban_or_bic):
    """
    Returns the bank name of a given German IBAN or European BIC.
    In the latter case the bank name is read from the SEPA Clearing
    Directory published by the German Central Bank.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00z\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x020\x00e\x00e\x02'
        b'e\x03d\x01d\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds\xd2)\x00\x00PYARMOR\x00\x00\x03\t\x00a\r\r'
        b'\n\t4\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x92)\x00\x00\x00\x00\x00\x00=\xf2\xa6\x93\xf9\x8a\xf7n\x16\x0e*\x9f\x9ep\xb3)\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf8\x85'
        b'\x02\xde\xba\xd9\x16\x9aE\xfd\x0b\r\xe2a0\x8e\xc4\xaa?N%\x89\xbb\xf5\x02\x1f\xa6-\xa9H\xa2\x88GG\x1a\xb83z\xa1[\xfc\x05F)\xc1\xbc\xcd\xfc\x08<6\x9c\xd9s\x19%\x87B\xb4\x0c\xe6\xfb\x1e\x10u&'
        b'\x1aFl\xd9!\xb8\xa5\xc7\xc0\xa1X\xae=xmKz\x96Q@\x9c2\x7f\xf5\xdd\xe2\xb5\xddO\xb6C\x9b\x1a\xcdk\xf0\x85\xb4\x99DS,\xbb=\x82*\xa3\x13\xd7\x15\xdd=\xbdDG\xdd\xba\xb6\xe4T\xdb\xf0U8'
        b'$\xca\x05WZ%+\xfe6\xdf\xe1\xfa#\xcf\x1dv5\xfc\xcc\x15\x9a\x17\xaeRiY\x08\xa4\xf3\x04\x14"[bQ\x15\xbe\xfbg\t\xfa\x8ak\xb2\xc7\xd8qG\x80\xeb\x03\xad\xd1E@\x91\x81Sy\xef\xfai\x9a\xc5'
        b'\xb1\xffHx\\=Oe\xbf\xecO]?\xebAL\xbe3\xfc\xbb\x81\x9e\xab\x8c\xc6]\xb5w\xc6\x00B\x96\n\x1e7\x13\xd2\x18W\xb3n\xca\xba2\xb7}\x0e\xb23f\x18\xf8\xc0\xd9g\x7f\x84\xda\xcd\x1b4\xdb\xac '
        b'^\xa4\x840\xde\x00\x00\xf0>)O\xef\xbb0x\xa3\xf6y\n\xd1b\x82\xdd\xf2\x03\x03\xe0\xe4\xd9\x81\xb6\xbb\xa2H\x1a0\x02\xed]w\x16C\xe5\xc3\xf3\xb3\xebt\xb8\xd1\xbbk\x9e\xc9C\x91\x06yl\x80\xe7\xef\xdf-'
        b'B\xd8\xef\x9bmA\xb2S\xb5S\x0c\xdd\xf2\xb6\xe3\xc8\xaa\xc5\x06s\x81\xbd\x1c\x92p\xe5\xe4\xea\xefD\xd5\xd6\xea\xcc\xe7\xb6\xc8\xf8\xa9M\xe5 \x0f{&\x92\x85\x9e8m\x04\xba\xcf3\x95\x0c\xd7\x8f\x89\xa8\x95\xb3\x80,'
        b'\x07\n\xe2Q\xb1\x7fR\xc1D\x93U\xe1\x04;.uS\x9cq\xda\x9fO\xbf\xf6U\xff\x1e\xabL\rpv\xa1\x83W\x14\xe12\xf4\x92H\x92\x189,\xdd\x01\xfb\\\xa9\xd4\xd7\tC\xe2\x13B\xabt\x14\x92\x06\xc7#'
        b'\xe0\x98\x97\xc8\xc3N\xfaY\xf0\xa0\xc0\x06\x84Vz;+n\x86\xb7\xa2>&J\x190\xbf\x9f\x99\xcaWp\x8a\xa1i\xda\xcd\xce\x98}\xff\x1c#\xdbj^\xe3\xfe\xfe\xc1\xa6>\\\x9aG\xe9-\x99\x83\x9f\x90\x0b(N'
        b'\xa2u\xb5\x1a\xea|l\x03;\xaa\x82\x08\xed\x89x1\x0cj\x05\xf6\x1d\r\xf9m\xb1m\xbf\xe0\n\xef\x83I\x0by\x95\xad\xfcm\x10u\xbd\xf8\xc8\xd4\x9a 7\x96\xa9\xa7\x14`fQ\xab \xcb{ \x0c\xaaA\x98]'
        b'\xeb\x8f@\x83\x9d\x07\r8&\xc5\xe2\x99\xa1\r\xe4l\x18\xa4\xc4P_P\x0cI\xd8Y\x9b\xf4t\x19\xd0\xc2t\x9d\xb0{g\x1c\x19\xac7\x82\xfc\x8aV\xba\xd5\x01\xf6\x0b\xd0\xe6\xeeo\x12\xc7\xa6$\x89\x1f];\xd5c'
        b'"h\xba\xbf~\xd5\x08<\x03\x05qs\x19&i=\x0cf\x03\xf5d\x1a\xa4\xa9\xa1\xb3V\x84 m\xf2\xc4\x02\xe3\x0b\xed!\xcbw\xb0\xe7\x11\xba\xc12\xb2\xb0\xe8\xe0\xdcB\xd2\x11@\x7f\x04x\xac\x89\x03\xc9\xfaMj'
        b'^!F\xfb\x8c\x1d\xa5\xee\x8a\x9c{az\xb0AuS\x17#"\xd6\xbeX\xff\x13\x84\x84nM\x11\xbe\xd3]v\x17\xd4E\x9bC\\\xb7\xae\x17\x02;\xf58K\x86a\xab\xd4\x86\xa5\x8d\xb0E\x13v@\x9bG*`'
        b'\x06\xc4\xd749\xa0\x80OM`\xf0\xed\xafd!>)c\xbbo"W\x06Z\xeb\x05\xf7\xfax:S\xf3Sh\x90\x83\xea\x10\no\r\xf6\xc4\xbfU\xac$\xb4\xbbp\xe8\xbc\xa7<\x04\x8d\t\x80\x90\xf9JD\x86\x01'
        b'\xf1\xa8\xa8\xeb\x8d>\xd8Q\x1eXtA\x94\x98\xbb\xf4\xb4}k9)\x8e\xb94Ss`i|\xbb\xfa\x9a\xd1\xc4\x9b\xab\x96\x94\xce\xf4\x1c+\x93\x94\xed\x0e\x8fi?m\xe5\x11@\x85\xbfI,sZ:\xb1\xb6Q\x1b'
        b'\xbbU\x8f\x08\xf9\x14\x17\xf2kAy\x0e\xa0\xd3\x0e\xcc1\x9d,\xb34\xeaD\xdc\xf6J.)\x04?\xb7\x1e\xf6\xd8\xcc\xf4\x881nKH\xa1\xa7\x1a\xcf\x8b\xf7\xc6h\x1e\x90aU\x8d\xf7a\x01\xe3\xf9y6&\x9d\x04'
        b'\xfd\xecc\xcc\x9a\x15\xef\xdc\xac^\xbc\xebp\\\x0e\xd4\xd7^\x9f\xaf\xee5]j@$\xaa\x0cU\x10q\x0f\x015\xa14\xb6PO\x0e\xcdb\xb6k\xc0\xe0G\xd3u\x94\xc0\xd3C3\xac5u%\xfd\x85,v\xcf\xab'
        b'\xc6\xc9\x11I\xbc\xc7a\x11\x08\xf3\xc0l<\xac0\xb9\xb5"{\xd8\x1d\x0c\x0b6-\xd6\x9d\xbe\xf8\x1d\x15/\x16` z0H\x81\xcfI\x10Y\xbe\xb8\x91wz\x10Q\xe4\x8f\x82\xf3\xa9\x8baI\xf3\xc0\r\x89\xc7\x17'
        b'\x91\xac\xf3iH;\rZn7\xebu\\Oc\x1b@\xb6\xbf\x15w\x07.\xe6\x0eU\x0f\x9e\x18\x14!\xfb1a\xe3X;\x87\xaa%\xb9\x1dG\xe0r\x85Z\x80\xb7V\xafNZ\x93U+\xcd\x19\xd3~\xc6>\x83\n'
        b'\xca\xea;\xfc\x92]Wu\x9b\xae\n\xb5\x19\x8cK>\xb8v\xb3\xe3\xec\xc2^\xa5Gc\x07[\xbeil\xf4:\xec\xb3BU\xfd\xee\xa6\x89\xdcR\xae\xf5\x1f]5">\xf2\x13\xc6\x9e\xb0b\xf2\x04\xe7\x9e\x80\xc4\x1a\x1e'
        b'\xc2o\xd4\x81\x81^{\xefZ/\xaa\xa7\xfdP\x17\xaf\x94\xffkKC2\x94\xb4b\x17f\xe0\x86\xec\xfb?\x1ds\x96\x9f\xe2\xb3-D\xdaN\xaa/[u\xdc93\xe8r\x94!)\x1a\xbb\xb6\x07\x05\xdd\xe3\xa0I}'
        b'\xa9o5V\x93\xcb\xb7\x9aO\xa97\xb6)w\xd39C{\xd9/n\x91M\xfe"U\xf4;M\xe8d\x8b\x16\xdb\xd8\xbcC\x87\xda"\xc0\x07\xe3\x8e\xf7|\x01\xabz\'\n\xeb\xbc)\x0e{$\xee\xa3\x9c"5q\xe9'
        b'\xc6G\x83\x83]\x94\x02\xc3!N\xf2\xc2V\xee\\\n\xed\x99`^\xee\xe8\xd1I\x1bdW\xa1\x91\xfdfU\xde\x0e.\xa5\x14z\xce\xaf\xdb\xe61\xbbvYkI\xa9j%\xbc"\xb6\xc8\xd3o%\xf9ZJ2\x05\xd3'
        b'\xdd\xacq\xcdn\xfc\x8a\xbe\xda\xc0b4\xf8 8D:\xfdIEh\xe2pd\xaeLT\xd7\xbe=\x9b\x87\xc5={\xef\xc26\xbd>\x0bl\xc9\x97\x83\x01!M\xa5\xfcI\xce\xfe\xdd\x04\xc2fK\xff[i\t\xc7\x11'
        b'\xbcjVQ\x80\x03\xde\x8f\x1a\xf7\xbfP[~\x9d\xed\xb9\xcc\xc1\x89\xaa+\x85\xe2q\xa7\x08\xad\xd6G\xa3\x12b\xe3\xc1\xf2\x81n3b\xe5:\x02\xff\xefg\xc4}\xc4R\x9c\x16\x9b\x8e?X4\x9bR\xc385\x19R'
        b'\xfb\xfeXI\x07\xe2\t;\xd1)\xdc6+\x1d\xc6\x13\xb6!\x04\xf2\x8a\xfa\x84\x94\xc6TTG\xe4\x16\xff;E\xba\xac!\x85\xb5p\xcde[\xd1\x80\x186\xae.o\xaa:\xbd\xf8jK\x8eC\xbf\x04\xdaKY7\x0f'
        b'/|\x99\x0c\xea\xcai\x92\x91\xe4dc\x16\xdcC\\\xa1#\xb8\x90\xb4\xee\xa7I\xdd\xae\xe4]\x00V\xe7,\xe1\xee\xeaT\x99@oli6\xd2F\\\x96\x9c\x16\x03~\x1eD\xcdq\xb4\x047\xb1\xca\xe3\xf6B\x10u'
        b'\x93\xb4d\xbf:\xc27Hi\x99\x91\x9b\xb850\x88)\xdc5R8K \x83ovb3\xcc\xb7\x81/\xe5\xd4$\xa9c\xe5\x1a\xa1\x1eN.\xd6\xf0\x14\x95i\xdf?\xdf\xde\x9f\x01U<\xd0\x1e\x18I\xdf\x11\xedy'
        b'y\xc2`.C\x1a\xb9\x85\xa1\r\xa9\x88`WS\x1c\xe5\x1f\xda\xc5l\xb0\x7f[\xab\x14y\xb0\r\xc5\xe4\xdbt\xa2\xd1\xfb\xce\x9fI\xeex2H\xa9,S\xd2\xd3\xf82\xcc\xd8\xc1:|\xb0W\x08\xc8\xf8\xe7!\x82%'
        b'\xe9r/\x93s\xe7\x1c9\x1a\xce\xcf\xc2\x86*\xbeC,\xabok\xb5\xb95\xeb\xc1\xaa\x13\x90w\xbe=\xf8\x93\xb0m\xc1\xd3\xd6\xf3f\x81\xe9\x05j6\xdcfyHpA\x0e\xe2\tC\x07\x19_\xb2t\x85F\x16\xe5'
        b'\x1a\xb9O\xd3\xcc\x97\x9e\x9a+K\xde\xd1Q\xb3LD\x15\xa5\xd1\xce\x08\xc3\x9cG\x07\x12 k\x96\xc7]L\x07\x1e\x85\x8b\xb2\x14v\x19\xe9\x11[h;\xceNX\x7fK\x0e\xba\xa1e1\xf9Q\x84\xa9N\x84\xd1\xf7\xe7'
        b'\xd0\xbc{\xef\xb2\xef%\x12zI\x9c5\xc4\xe5\xe2\xe4\x193\x80\xb218\x1d\x94\xfb\xa5\xf9%\x82`7J\xab\x80\x91\xa2\x87s\xa2T\xbdhX\x8d\xde\xf4\n\xc1\x1d\xd9N\x0b\x9b\xce\x9d\xa2\x13\x9e\xf3\xdb\x89B\x11,'
        b'Y\x1dB\x02\x9e\x88\xeff\xe5\xc5P\x89\x04\x9f\x0f\x87\xc57\x8c\xa5\xcf\xa1\xea\xde\x7f%\xa4\x05P\xcc^\x85\xea\xaaq\xc7\x08\xee\x94K\x8f\xe53\xceD\xca\xa1w\xdfTv\xb8\x88A\xa9<qV\xa3\xb0\x95^n\xae'
        b'\xd7\xaf?\xd2a\x1c\xa4\xdc\xf5N\nk:\xce\xddu\x80\xaa\xef\xc1r\xb5u\xe9\xad\xd8\x85\xd1\x14vp9\x95b\xccdR,gh\xcc\x8a\xbe\xd04\xc2\x167)_\x81\x13X\x02\xfakE\x99\xd2\xbe\x82~\x9a\xe8'
        b"'\x94\xd6J\xd4\xde\x8e\x1043\x05\x81\xbd\xaaD{YR\xbd:I\x9f\x95O\x89\x1c\xe6\xe5\xec\xa0.u\xdf\x88\xe1\xa1\xa0\x90;\\@\x1c\xaa\xad\xa5'\x05\x93\xf1\xbc/\xf2s\x8d\x87o\xdfta\xce\xff\xeb&\x7f"
        b'g\xbd\xad\xeb\x05E\x0c\x83\xde\x04/y\xd3\xdf\xce\xa8w\x1aUy|\x0e\x9e\xd9\xfa\xc0\xab\xd8\x97\x89Z\xa6\xa3r~\xb9=\x1c\rRZ7N@H}\xb5\x9a\xf37\xad\xc2\xac\xca\xfc}\x0c\x1c:I@\xc5Ux'
        b'\xae/\xf4\r\x0b\n7\xd8W\xf3\xaf\x16U\x07~z\xdf\x8bU\xb0FA\x1c\xbbpk\xd3U\xed\xcah\xaejm\xbd\xe8]\xa3\xa4\xabW\xbd\xc0\xea\x92\xa0\xa1\x86\xab\x81\xc0\xba\xdf\xb5\xf8\xc3^}\x86\x0cs\x8d\xe2\x9a'
        b'\xaf\xf2\x13@\xaf!FsAk\xdd\xc0\x85\x18\xd8\xb4f\xfa\xa2_\xed\xb8\x86\x04E\xd0\xb2\xe3\xcd(L\xe4\xda\xc4\x01\xd9\xb2\'\\4"H\xf7<5N1\x11\x85:h\xa4^\x858\x8dGt ]\xa5jag'
        b'.e->\xd8\xecQ\x93\rY:\x84O\x88=\x12=\x03z\x0b\xf3\x85w;\xaaF\xc6\x9d\x18\x8b$\xa0W\xf0\x97\xb9\x8d\xc2\xc2"(\xc3\x08\x16\x15P3\xe9&\xedqJ\xf7\xc1\t\x12\x01g\x17\x94\x02\xc9\xd2{'
        b'\x83^u\x03&\xb1\xe0\x12`\xd2\xaf<\xe3\xa8\xd3\x13\x0b\x1f\xa2v\xd0\xa9{\xab\x1a\xa2`@\xfb[B\xcd\x18\x1ba\xd0\x9fc\xcd\xf4?\xc7\x99\xc8\x80\\\xe6%\xf0\xfdo|\x07\x05&5\xa4\x16\x91M\xd1\xac\xca\x07'
        b'[A\xbbH\x1b\x0e\t\x9c\xec\xfd,\x14\xf0@\xeb\xbb\xcc\xadv=\x95\x89\xe6\xd5^or\x0b\xb7\x8c\x9e\xbaM0\xd5\xabxsL\x13F\x81\nu\xfcB5\x96=\xfb\xeb\xef2P\xdab\x1aX*2\xdb\xd5\xe2\xe4'
        b'\xccud\xf8\x91\xe3\t\xeft\xfe\xb5i\xda\x19\x8d\xa0\x00\xce\x92\xe3\xac\xd55\x18\x1f\x86\xe7\x10\x96\x1c#\xb3\xf2k!\xab\xcfH|w\x7f\xf4\xaf\x1beH\xab\x9d\xd20\x8b\xa2\xd1\x189\x8bf\xd1\xaf\x94\xa7\xdb\xd9\xb9'
        b'\x9b\x130\xa4\xb5\xbe}R\xf4u\xda\r\xb5\xcb\xc6\xd1\xb3\x9e\xf1\xb6\x1a\xd1\x98\xccg\xe2\xd0\x11\x9eD\x0fW\xb4\xec\xff\xbd\xf0K{\x1a\xa2uP3?\x14\xfa\xeeJ\xf5\x9e\xbbz=i?m\x1b\xc6\xfe\xf5\xca\xfdR'
        b'"\xceI\xd9f\x05\xf8\x0f\x89\x8c\xb2>\x03@<\x8e\x08\x071\xa7\x0b~\x8d\xd7\xc0\x89\xdc\xfa\xe0D\xc2jl\xa2\xfd{\x7f\x04\xd8\xb6\x84O\x8dS\xed\x06\xb3o\x17\xb6\n\x18M\xd0\x94(\xaf\xa5\x9a\xfe\x17\xb0\xf5D'
        b'\x07\x14MU\xe1\xdcc\xef\x0e\x1c.7\x1f\xa1\xcc\xdaH\x97%NdJ\xdb\xc3q7g\xefS\xab\x07\xbb\x035U\x99o\xcdc\xb9\xc3VVm\xb3pE\xb3\x0f\x19\xf9Z\x89\n\x04J\xe5\xf1\x9f\xd6\xe8\x0c\xb9\xb7'
        b"\x11\xe7\xfb\xd2`h%\x91?\xddqJ\x15\x89\x043\xfap\xfb\x14J\xc1D=\x86\xd2\x06\x97\xc3\x95\x03c\xe0l[\x97\x1f8b\n\xd3\xf3\\t\xb3\x17'\xd6\xb9WyY~\x1b\x13\xa1\xb4\x9d\xb9\xfa\x9e\x85(~"
        b"f%\x91\xf1M\r\xc5\x07h\xccq7\xd1H\xd9\x9f\xde\xda \x9cu\x9d2\xbb\xbe\x18\xc8\xebE0z\x16+U\xb2\xf7\x99\x99\xecii\x80q\xe9H\xc2e\xd2\xbd\xbe?\xe3\x1f\xfa?(K\x13`@\x9a\xd9-'"
        b'\x0e+\x99\\\x9f\xd3\xf1\xb9j\x19n\\\x8c\xd3_\xa02s\x11\xdf\xf5e\x89\x18u\xf1\xf7v\xab\xb3(z\x1b\xbeC\xf0\xcb\xd6\x7f\xca\xfc\xd1\xa9C\x070\xdde\xee\x18\xc6\xd8\xcc \xe7=\xa6\xb9\x9b+\x1d_\xf1a'
        b'\xbd\xa0\xa3\xee\xef\xe3\x97\xd4\xb8\x96V\xbc\x92C\xe3O\xf8\xc9\x93,\xb4\x17\\\xb60\xf0\xc5=\xfa\x1f]\xf4\xe1\xa7\xb4s\xe8F\xd1\x17Y\x99p\xcf\x84N\x04\x14u\x83\xd99-\xfd\xacUD\x8d\xfb\xd6\x90kk\xe5'
        b"\x80G\x9b~\xbc\xcb$K(y- \x9bl9\x14\xfd\x17?\xf30\xf1`\x88\xff\x01+\x97\x9f'n\x8bDu\xc6\r<\x95t\xa3\xb06m\x81\xc9j\xe9\xf2Y\xa1W\tr\x17a\xaf\r\xfd\xdc\xec\x88P\xfe\x8c"
        b'u\x9b\xa0\x13\x87"\xcc\xc3\xfd\xf2i\'\x8d\xf6\xfb\x1ff\xc0\xa7\xdcj\xcc\x98\xff\xd3!A\x17"\x98~!\rPp\xa0\xf31)\xaa\x85;\x01G\xa8\x8e\x04*d\xe8]\xfe\xbc\x18&"\x01;^\xd9\xb9\x97\xe1\xd1'
        b'\xfa\\6\xbex\xb5v\x1d\xdc5\xedJZ$\x1d\xba\x0c\xe2e\xb6\x1e\x02 \x01\x11X\xec\x07gW\x19B\x97\xb1e\xda\xb8\xe7%\x8e\x18"\xd3q>iu\xf7\x85\x11\xd4`\xf4C(\xebsC3\x1a\n-\xdf\x83'
        b"\x91\x0fi\x85\x07s\xfb\\\xba\xceA\xd3e\xa3\x8fX\xc6[z\xe1\x81\x14p\xa5\nL\xe6/\xaf\xb3{]\xa0\x8fK\xc33\xf3\x15\xb0\xb6\xb4\x9f\xaad-y\xc9\xfc\n\x01\xd7l)'\xc1\xe6\xda\x82\x9a\xf9V\xa7\x02"
        b"vJN\x87J\x90\xe9\xe6D\x03\xddp\xf2\x08&\xca\x1e\xb2\xe3Dd\x898\xce\x88\xee\x96\x03'|2YD\xf5\x9c\x8a\x90\xcf?\xa2\x15sh\xd7\xbc\xf4\xea\xc8\xcd:\x19\xf6\x81\x91\xd4\x05\xb4\xfd7\x00\xa0\xc6\xad\xbb"
        b'\xa2}`\x9fqss?G\xfe\xaf\xc0hx\x9f*="\x14Z\xd5<\x8c\x0e\xb4\xb1d\xce\x90w-\xaa\xab_8\x17\xed\x9cR5<\xf0\x7f\t\xfag\x003\xe84T}\x97\xb0p"\x83\xe9\xec\xc5\x96=T\xe5'
        b'\xac\x18\xa7\xb0I\x8e\xbb=?\xd0\xaeu\xc0C\xc3XD\xc3wM"u\xaa\x05\x19\xf8N\x92E\x83\xd9\xc7\xec\xbfY\xc5k\xbae\x16\xf7\xe0\xcf\xf7G\x1d\xe3\t\xe7&\x84\xd5\xe9P\x1ap/\xf7\xd2\xe2MQ+\x83'
        b'\xe4>0\x9b]\xb7h\xc1\x99/e\x02\xb1=:*~(q0\x90a\xe2\xc9\x06\xf4\xd5\xf7\x99U\xb3w0\xdb\xf1\x87\xf9\x93mK\xba\xbf-+@\xc5[{%\x84\xcfs\xb1\xfe\xe7\xe8h\xe2Mo\x019\x9f\xbd'
        b'\x17\xa0\xb3\xd2\xba\x9eB\xa3c\x0e7\x1e\xd8\x9d\xe6\xd6(y?=s\xfb\xec\xcc=\x88\xec?\xe1<\xa6V\xecC\xc63\xa3\x9dT\xf6\xc8\x92\x9d\xd4\xbf\x115\x8c\xa2\xda(\x16\x983I\xeb\xcbN\x0c\xda\xa8\xc9\xceU'
        b'\xa9\xc2\rx\xa0L2\xecd\x01\xdc\x1c\x96\xda\xf6\xb0Y\x18\x1aq\x86%\xf0o\x19J\xd4\xf4s%\xc2\xe0\xb1K\xc1xRZ\x02\x17\xe3\xb2\xf2\x13\xb8k\x91\xe7\x81>\x10\x93\x18,\xd7pow\x11.;\x86I^'
        b'/\xd9TM0\xf6\x95%\x06\x86\xc1\xbe\xd5\xed\xe1\x88\xb2\x7f\xbf<!Q\xd7\xecn^\xd3\xe0\xdc\xbb\xaa\x86r\xd6\xa6Z{\x19%`J\xc1\xb7\x02*\xfd\xb8K\xdd\xeb\x9fp\xe6\x94HoH\xed\x10\x1e\xe8x\x95\xf7'
        b'~\x1c\xf0I\xcbB\x03\x12\xea\x19\x951\xf2i\xfby\x8b\x10\xd7\xd2\t\x19\x08\xfb\xf5\xff}e\xd1\xd7a\xf9\xe74?\xf5\xd2B\x98\xd2\xf1\xb1\xa7d\x8cU65\xed\xe1\xa2\x9b\x88\xa8\xb9-n#\xeb\xf0\xaa`\x98c'
        b'\x044%\x14\xe7\x11\x95yh\xa4\xac~\xf4\x1a\xd4\x0f\xd6/$\xec\x9c}\xf7\x7f\xfc59\xf1\xdc3\x85\x13@X\xe5\xcejL\xd5\xf0\x1d"\x0b\';\x1b\x1d\t/X\xab\xe24\xb3/7\xc70\xcb#\xb4Ha\xd0'
        b"~\xb9e\x1bp\xfdI\xea\xeb\xa1\xbd\xd0\xec\xa19\x8b*\xe1d\x9c\x01\xb3\x1e\xea'\xbeVWZ\xb8\xf4!\xbd_\x11\xed\x0f\xd3\x08\xa1\x93 \xfc\xd3\t\n\xe7A\xcbH\xb0\xa0'\x1b\xbcs\xc1\x19\xbdw\xf2p\x9ae"
        b'\xb3\xd2\x85>\x92\x10rk\x80v\r\xccPB\\\xd71\xfb2F\x03tK\xe6\xbc\x98di"\x16\xed\xa3\x98\xff\xb4@=`nv*ew\xee}\x82\x84\xc6\xb7#\x1eK\x96T\xc0\xabm\xaf\xe2\xdb\xc18\\v'
        b"l&B\xffT<\xe5\x81\x8f\xc3\xed)\xb4)\xdf$\xb4\xee&ON\x1aC\xe9\x13~*\xa9\x12\xa1\x81\xeb\xb1\xf7\xa1\xc4\xca\xeb\x1a\x7f\xfc\xce~&Y\x0c#\x9206\xe1'B\xbe\x11~1\xc4P<\xc7\xc1G!"
        b'\x9dPK?\xbf\x06wC\x82\x0ffgc\x97k\x1a\xe4\x8bC\xba\r\xd5\xf9\xbb\x08\x99\x16:\xa5;\xd6\x82\\t\xe9\xd1\xf3?K\xad\tn\x83\xb9\xf9\x92\xa6\xfaI`.K\xdf|NVQ\xa6\xb9\xfeA-\xb7\xde'
        b'\xdf\t\x1f\xa9\xb8@\xf7\xfc\x01\x90\x8a:\xe9\x90\xa8\x193\x17,A\xf1\x97\xa5Yhb\xf4\xda\x9dS\xa1\x8c\x0c}}\xd9g\x8eN8*ko\xd8\\\xae\x7f\x86\xb5\xdbl|\xae\xfcuY\x00\x8c%[H\x11x\x0c'
        b'}\xedi\xf9\x9e[\xa6!\xe5\x1b\x177\xf0\xdcg&z\x9c\xf3L\xd3\xf2\xbc`\x86\xbd\x89\xc1\xb5p\x0b}\x85\xd2\xde\xc0\x9f#LQ\x83\xfe\xad\xc7K\xcd\xa3"NOh\xd8\xbf\xc8~\xca\x89u\x11|E0 <'
        b'+\xcc\xab)5\xcdN\x97\xa7\x97Z\xd5\xbd\xfa?j&L\x83\xd6\xf3\xedAK\xf5\x1d\x1d\x83\xd5<\xf4\x9d>1;\xdeHv\xdd\xa7\xd3VMb\x8a0\xeb?\xea\x12\x04\xe2}n\x83p&,\x8e\xa0\x8d\xb0\t]'
        b'S7\x18\xde\x142\x94\xb3\x15,\x04\xb6B!\xe28M\xbe\xe8\xf1F \xfaKIb\x8b\xe71F\xba\xb4\x1e\x86\xf0O\xa8\xf5\xd6\xa3\xa5\xc3^?#@\x1a\xf8*\x16:\xdeR\xcc\x81\x84\xec_bC\xf0\xe4\xd5\x93'
        b"\xb7\xb9\x94'\xe8@\x18\xc1\xe3\xbbm\xa2r\xf9m\x86\xe6\xb3\x1e\xebo\x18\xaa\x02\xa8\x15RS\x0fO\x17\x0ck\xa4f\xd3z\xe11,\x13\xb6I\xdb\xf5>\xe7\xb9\x8d\x00\xc5\xd1\xb0]\xce\x88\xe6\xa0C\xcf\xab\xff\xe5^"
        b'\xdb\xe4\xf9m\x16\xf05\xed\x0b\r\xd3k\xebuV+\xaa-X\xce\x99\x8f+ \xbd-\xbb50{/E_Mg\xe3eU\x98\xad\xec7U6T\xb9\xc3\xf4\xcc2\xfb\xbaw0\x19d\x1f\xb6\xe3%\x15t\x9af'
        b'{TC\x08\n\xd9\x9e"\x96\xb55\x96g\x8d\x15\xb1\x8bZ\x13?G\xfa\x01\xc6\x84\xa9\xb1G\xe50\xea\x8d\xd1X2\x12ph\x1cf:i|\x17(\x14\x9b\x9d,\xbd\x95\xf5\xb5<\xed\xab0\xe7\xec\x80\xd9\xc34\x81'
        b" 6\xdc\x18ZN\x91\xe6\xc5\t;\xaf\xa6<lg\x91L\xb2<\xc2\x07\xd3\xc5q\xe7!\x17\x0b\xcd\xe2\xc1\xeb\xe9\x82\x92\x045\x853\xb0\xf0\xa6Qu\xbb\xc3>\xd90\x15\xf0Y>\xf7\x80\x857!6'\xf8y\xab"
        b'\x98\xcc2\x9f\x06\xd4:^\x1d\x80\xee\xb27\x9dUp.\xbd\x1a\xef\xb2n\\ \x07\xfc\x13\xa1\xdft\xf8yeRf\x19D2q\xbb\x93?\xadq\x07\x01\x99\xd3S\xe0\xfd[#\x93\xd8C\x0e\x18\xdfI\xb1\x7fy\x0b'
        b"x~F\x85\x95!\x80P\xc5\xefD\xe7\xa6c\xbe\xe6\x05,\x0e\x11\x87\x18\x1ar\xfb\xd5F\xe0v\x1bt\x1aG\xb6k\xaeuf\xc5\x83\x11\xc0\xb0\xb9\xef\x9du\x82\x0f\x7f\xb3\n50\xbb\x8d\xce\t\x1c=kjc'"
        b'\xa3\xba(]w\xd9\x91\xd04\x86\x8cy\x1d\xd8\xb6;]\xb0\xe0\xf2\x98\x14]\x86L\x988t\xedk1\xa7HME\xc1\xab\xba\xe2Z\x175|\xe8\x1d\x8c\xd1\r\xd5k\xa3K\xd2\\\xca?\xce\xca\xb5\xf9\x89e\x11\x82'
        b"&\xa2\xdb\xfd\xdd\xb2\xecF\x06\x87H\x83i9\xdc[\xb2\xdc\xe4&+7\x01Eowy\xed\xd1al=x\x1f\xcd\x9b\xcb\xbep\xd8Q\xbd\xbf\xa0>J@k\xa5\x8a\xf6hUe{\xa0\xde`'\xc8zt\xd9e"
        b'\xf9\xef\xd2\x14\x9b~\xaf\x06\xd6\x80\xe6BV\x8e6\xe8i\x9b\xe6\x1d\xfb\xec[\xcb\x99,U\x0f\xdd\xf8\xe6a7\xa8\xef=)\x86V[\xd5T\x18\xa7oS\xd3\x14\xd6\xd5\xcd\xb5\x01\xedz\x05!\xaf\x7f\xc6\xc0\xe6iP'
        b'\t7\xeb\x0e\xb1\xdd6bfu\x03\xbc\xcd\xbc*\xb6\xaeq\x84\xa8\xb9\x04\x1c\xc8[\xcb\xc3\x94\xfc\xab\xd6\xab\xd3`\x85p\xff\xc1\x8f\x05\x0f\xc6\xf91+\xceiQz\xa0\xc0\xf6\xc7\xeb3\x17\x9a\xa8\x84\x8aT\xe6\xf6\x17'
        b'\x1d\x93qo\xf5\xd6\xfcY(\xf9\xd5\x82)p\x9c\xe0@!<\x81\xfb+\xf2\xe9\x06B\x8f)\xbe\n\x08\xea\x03:\xe9\xd2R\xcdZ\x9b\xab1\xd4,\x112\x04\x96\xe1!\xa0\xd2\x9a\xbe;:$\xfa\xce\x1d\xf3!\xa2]'
        b'\x9a\xa1\x8dU\xe6\x7fk\x93\x0f\x1f,:6\xcb\xdf\x17\x9b\xa77;E\x01\xc9\x84\xfc\xf9\xc6R\xe6\xc5\xf78\xc3\x0bw$\xf4t\x89 K)\x9a\x10I\x9d\xd7\xb9.\xce\xfc\xef\xe0\xd2\x9c}e\x00J\xea\x7f~x)'
        b'\rW\xeck\x16\\\x94\xa0\xafP,\xe3Y\xbf\xfa%F\xa4\x1f\xc9\xc8)\xc1\xb5\xcfX\x16Y\xc2\xfdt\xd7 B\xec\xd8\x88a=rb\xe3\xc9\x97;\x8b\x01\xc7/d\xd2\xb7\x8f\x0eB@L!\xfdi\xe7\xf9]\xa7'
        b'Y\xd7Yj\xce\\\xe5\xb95\xf2\xb1\x11\xd5\xc2\xe44\xba\xc1\x810\xeb\xf3\'\x0c\x97\xa0\xf1\x8f\xad,N\x0b"<\x8b\xdd\xc0\xa5\x91A\xa2_\xe9\xaf\x80\x99\xb2\xbb\xcb=\x0b\x17\xd1\xd5\xa1\x87\x9a\xef\x91G\xff\xc8\xd7\x92'
        b'\xc7?\x0b\xaf\x10\x7f\xd7C?\xd0\xe2k\x05\xee5\x0f\x82\xfaiTnI4\xb2Uh\xd6\x17\xe9\x80\xb1\x9e\xeftP\x06\x1b-x{`\x03\xf2\x07\x12\xa4E\x82\xady\xf2\x03\x94\xd5[\t\xd8\x1a\xf7\xba\xe3\xd7\xea\x8b'
        b"\xffC\xed/)\xbao\xf9l-\x15/y\x12\xf6\xb1\x05a\x8b\x1d\x0c\xf6[\xf3\xfc\xa7\xc1\xb9k\xac\xce\x19\x00\xc4\x96:[{'0+\x0c0\xe0\x87\xe0\x15Xo'\xd1,M8\x8aK\rc\xbf\xaa\xfc\x7f*\xf0"
        b'\xcb\xef\x83\xb0\xa14p\xc6\xf1\xcb\xcf\x19\xffJF\xc7\x89Q\xdf\xc2\x1e_U\xcc\xd4\x7f\xd7\xf4\x95C\xb5\x19\x10\xd0_\x03\xae\xed|\xd2\xeay\xf8\xbb\xdc\x16\xdeb\x8c\xd1\xe4\xf51\xf1\x80S\x1b@ y\xeb\xc1vS'
        b'\x14\\\xea\t\x85\xb1\xc5\xb5\x0f\xd2f\x8c\xdb\x994\xadz\x96\x99K\xb7\x96\xc3\x94\xb4\x9cO\xf9\xc5\xd9gQ\xa7GEv\xd3\x84\xbbpe\xcf\x17,uQ,|\x1es\x1b\t5O\x11C\xa2?g.z\xe0\xf7b'
        b'}\x8eD0\x01}\x98\\n\xb7\xc3\xb4\xae\r\x87\xfc\x9c\xa6\x1fA\xde\xfb\xf7\xd3\x1bM\njq(\x8b\xeb\xa5|H[\x06\x11\xdekT\xc4T\xf6\xf8\x1da~+\xea\xeed\xd2Zml\x9b\x9d\xdf\xc8\x15\xa3N\x13'
        b"F%z\xdfr\xd8\xb6D8%v\xec\x92b[\xc21\x1fmPjwVc>*q6\xdb\xbf\xe3\xa1\xb7\x9f\x1b\xdb=\x01\x04Y\xafd#w\x9fP'\xca\x9e\xae\xe6<\x97\x9az\x0f&]\x91\xc6 \t\x98\xf0"
        b'\xd4\x88\x01\x8aW\xd4\xcf\x1f\x8c\xfe.\xb0\xf2\n\x84}\xa0\xee\xacT\x9b\xc2<1\xcf\xd9\xf9\x91\xd6\xe6\x00\xff\x1b*\xa0;\x85\x07H$\x88K\xe1\x8f%\xed\x96\xee?\xa0\xe0:\xdb\xa4\xcb\xf7\xca\\\xcf\xef\xceG\xbdI'
        b'\x86D\x8e3\xe6h\xf7\x1e\xa4R0G\xc5\xb0W|QFi\x8a\xc9K\xb0Z\x16\xc9\x11\xe3\xba\x14M%\x81\x0eN=\x01\x86\x17\xd4N\x9c[\x07\x15C\xd4 C\xa7\x0f\xd2\xddV\xeew\xb3\x8eh?\xa1\xff\xb4\x7f'
        b"\x89\x1e\x00d\xcc\xbb?\xd5{\xe1P\xe7e\x9e+\xe9c\xa5\xfe\xd2\xcf\x1c\x99r\xba\xdb\x000\xd0^\x92\xef\xfc\xc3\\\xb1\xbf\xe1\xd6f\xedk\xa32\xbc\xaf\x97\xbf.'fw\x81\xe4\x1ak\xda\xa24\xd8\xdaa9\x0e"
        b'LC\xd0;\x93N8\xea;y\xc1\x07\xd3\xd5\x13\x9b\xadhH\xb7\xfa\xd4u/A\xfd\xd0<[\x992\xbb\r\xb7\xee\x9b\x95\xbf\xb7\xffJ\xa9\xa4\xf6\x85\xc9\xc4\xa7\x0c\xb4\x89\xa9\xf4\xab\xf5\\\x9drev\x96\x7f\x983'
        b'yo\xbe\xc8\xaf\x902\xea\xd6\xce\x0ba{\x06\x91\xb3\xdb^\x1b\xad\x13\x02\x8d\x15\xa3\xfejE\x99\xe1\x98\xf1$9\x8a\xfeD\x1f\xa2\xf0j+{3\xb0.\x13D&\xd3m\xcd\xf4\x02G\x1cw\xd3\xc5\xbfQIB\xd8'
        b'\xff\x83X\x91\x89 t\xc9%5Oi\xb2#\xe5\x07\xe4\x84\x05\xdf\nX~\x8fEc0M6\xf8:f6]\x00\xc5]\xdct\xee\x8c\xf0\xbe\xdc\xb4\x90\x94\xe1\xd7\xdf\xb4p\xbcQ\x11\xf9\x10\xbfu(\xa5\xf5^K'
        b"\xb7\xc2\x8b1\xbf\x83\xc8\xceC\xbcm\xf3y\x7f\x9c\x0f\x1b\x95\xb2\x94~\xc4K\x94'\x10\xea\x83\xee\x84_\x90\xa4 \x80\xcd;\x0f\xa5(>A\x1a\xeb\xf0\x95.\x9bPX\x02\xed?\x19\xc1Q\x1a\xae.\xf8\xb6\xfad/"
        b'\xa8\x9f=\xf7\xf8\xa0\xa9\x7f\xe7\xe4\xc3\xad\xa1W_\xc1\x8e)L\x01cdT"N\x0e\xa3\xff\x8d]\xb7\x92\xeeE\xa4\xfd\xe6|\xef\x11\xe0[\x9d\xc3\xab\xfb\xd9*z\x9d\x06\x88\xd3G\x0e>z~*lr\xc5\x10\xf3'
        b'Z\xd3\x04\xb5\xfb/\xf82\xa1\xc7\t\xbd\xf1z\x9f\x17R\xe7\xad\xa2\x87F\x11Q\xed\xe8P\xa1\x83\rar\xd5\x89L\xcd4\xb7K0LJ\x04\xabjv\x1c%\xca0\xd4t\xfd\xf0w\xf9Q\xda\xf3\x04<#\xb9\x95'
        b'\x8c/sr\xf9\xb4|\xfdq\r\xfd\xf7t\x98\x7fV\xbc\x88\xee[\xc9\xd6\x9bS\xd6\xca\x1c\xb9\x1aCd\xdf\xfdM3\x96.\x05\xc2\xfa\xear\x9eD^\xc38\xce\xdd2s(1\xaa\xdc\x161\n\xbeX\xab9T2'
        b'\xf9C\x1br&\xc3\xa0r \xafK\x13\xd2\xa0\xfa<F\xba\r\xf1\xde\x91\x13Z\xd5\xb2D:\x89\xe7,\xb7\xb0/\xce\xbf\xf70\xf8B\xc4\x17N*i\xd4c\xa0\xa3\x17\x96-\xa0Ao\xe7\xd4~Vz\xdeT\xb0\xd7'
        b"\xde\r\xfe\xd5\x10\xfaIx\xf9\x1c&\r\xb6)\x1a\xd8\x8a\xcf\xfeMp\x1f\x11h|\xfa'\x8d\x94\xae\x84r\xb9\x14;\x8f\x1fc\xa1^\xa5\xefR\xd8[\x8b\x1c?\xado\xc5\x16\xd2\x83k\xf3\xa7\xae\xc5\xc8=\xe2\xdb\xcb"
        b"\xbf\xbf\xd3#\x8f\xec\xa47\x92W\x16(\x0e\xdd*\xbe8\xc89\x84\xc4?P\x88\xb6W'\xc0\xd95\xdd\n\xa3,\x8f5\xf2\x99\xe8\xe4\x95\xe0\xf2\xf5\xdc\xb5\xfcK\x1b\x94\xd1w\xb7Z\x06\xbc3n9z\xa1\x98\xc9u"
        b'\xc1\x91\xff\xd4\xba\xcbu\xa5\'\xe0\x87\xae7\xd5\x94N\xd2t\xf9{}\xb2\x1d\xb3G58\xb2^\x01\xeb*\xf5\x15yu>s\x90\xca\xa2\x94\xee\xa7B"\xa9\xa7\x9dr\xc9\x8bG\x7f\x035\xa9|\xefo\xc7Q\xecA'
        b'\x10F[St\xae\x91\xfe\x90m;/\xf9\x84"\xad\xfa\x14\xeaA\xd9\x82t\x86\x1b\xa5v\xd3_\xf7\x7fc\xd3\xfc/.\xf9\x9a\xb5G\xea\xe5\x8aKK\x03Ni\xed\xef`NvLb\x98\xfb\xfd\x96\xea\xfa\x15\xed\x0b'
        b';V`\xa7\xa7U\xf8\t\x1e\x1f\x1e\xfbYS\xb9pq\xb7\xa0\x15\xdeD\xdb\xff\x9f\xe2P\xc9h\xc0U&r60\xdcV\x1a\xa6\xa9\x03\x9a\xaf\xd7r._\x05\xb7\x96\x95\xe2\xb5\xc3\x80EA\xdc\xfbD6\xf2\x8dg'
        b'V\xbc1o\xef\xca5@Af|H\x7f\x08\x0c\x10\x89%\xe13\xd3\x82 w>@\xb1\xa7\xf8t\xd3\xb7\x07Kahr\xfd\xe5r\x0c\x83\x0cvn\x88\xa3\xc2\xdfS\xae`\xea\xd7F{\x8b\xd5!K\x86\xda(\xba'
        b'1\x0e\xfd\xedX\x91\xfb\xf3lU\x94\x01p\xfbQ\xbb \xab\x1f\xde2S,\xb3r\xce\xd9\x0e.\x18\xd9\x02\xc1\xd7w\xd8\x11\xfa\xa2\xe9.\xd7\x088\xfbT=\xed1\x84\xfbg\xdc2V\x96\x8d\xaf\x89\x11\x8cE\xc7\xa9'
        b'=U\xe0\x8d\x88\xea\xe1h.\xa7:j\x04@\xc8x\xb3\x8c\x9f\x91My\x1e\xe1\x9e\xa3*\xfd3\xad9\xe1\xcaD2c\xd7o\x11\x91\xb6K\xd9\xbe\x99\xd8\xdd\x81\xd1\x87\xcc&\xdb\xe9 \xe1o\xc4\x02\x94pa".'
        b'\x97\x8d6\xf5%!o\xd7an\xc3\x97\xd6sq\x1a\x1b\x84.\xbe\x95\xed%"\xbd\xdcS\xf8.V\xec]Q\x90-\xb7t\xef\xa8<\xc6\xd1P\xe0\xae\x82\xc3&\xa1$\xe5\x14A\xad\x904B\xf2sVVSF\x8e'
        b'\x01\xfa\x9d\x17\x1dL\x12\xa4w\xcb\x11\xde\xcf\x14\xf2@\x82\xab\x90\x18]\xaf-q>t\x8b\xc4}B\x176\xa5\xc1\xb9\x00\xa6\xc3\xf7H\x97\xdeykP\xa3\xd8-\xee\xe6\x91.\x98\x17\xed\xe25!\xa2\xc1\x87\xdb\x82^'
        b'f&^\xc5\xe2\xaa\xcbA\x0cc\xb1H\x14A\x92\xd5\x99\x0c\xbb\x8e\x9c\xe4o\xf0m@m8\xbbX\xda\xb3\xa7\x06I\xc7\x98\xdaF\x88\x89\xd8\x9asu\x13\x91\xbf1Q\xb4E\xbbC\xd5[\xb7!(A\xa83\xf3\x0b'
        b'\xd0\x0c\t{\xcc\xc6\xb8\x9b\xf6\xe5\x9d\x91\xda\x07\n\xbb\xbb\x18\xf5\xaec\\\xcc\xea\x1c\xd8\xf4y\xc3\xbb^\x04*9\x83\xa0?\xb2\x93\xed0:)x\xff.W\xafM`\x8dy@\xb2\xc3(\x01\xc9\xa8\x02\xa9\xda\xc5\xf8'
        b'\x84\xf1_\xa6\x1e\xc7\x0b\xc4Z\xaf#\x9b\xb7\xce\x1c\xe2\xaa\xd3\xca\xff\xdcR\xea\x0c#\xe1\x1f\x19vo(\x05XYn\xa5\x11(9Z\xf2J\x14\xcbH\xe8{hR\xbb~=\x98t\xd9\x0f0a\x8e\x88Iu\x13\xe5'
        b'\xc9\xdaz\xc9G\xf1F\t\xf9\x88\xa8\xd6ad\x14\x14\xe7~\\\x8b1\xf3?\xbda\x98\xf0q&\xdc`~\x98\xbf[\xd6\x8a\xfe\xacD\x7f\xb1\x1cX-\xd4nE\xb3\x04\xd2\x9a\\\xb4\xd03\xf4Y\xe8\x12@\x8e\x92\xd2'
        b'yr\xf9\xfd\xce\xb5\xdb\xd5\x8c\xb8\x1b\xbe\x1d\x9f\xb0\x8d\xcf\xbd\x076\x91R\xc4\xa4\xa4T)5\xcb7\\\xe3\xb2\xe3lt\x94U\x8c,8\xf13\xd5:\\\x9b\x1d\xd4\x0e\xc0\xa3\xb5\xb2\x83\x1d$\xa5\xe8<o\x83\x01Y'
        b'\x86\x90\xfa^\x174\xf1\n*\x0cc\xe8F:\xb0\x08\'y\x88\xee\xe0\xde\xaa\xa0\xc3hw\xdc"ie\xae\x9f\xe1\xf0\xa0\xfe\xe1\xe6\x08\x90\xec\xa4D\xe5Z{y\t\xb1S\'/:[\xd5X?|\xd9\xb5\xeb\x11\x92'
        b'k:\x15\x9fQ!"\xec\x8c\xf5x\ng$\x0f?\xe6\xb3\x99~1[\xdc\xee<\xef\xa3\x16V\x97/-?\xa1\xba\xe7I2\x87\xdbQ\xcd\x08\x88\x84/\x19\x8a?hg\xac\xe7?\x87\xb1\xa3\xe1S\xe1\x1a\xd0\x00\x07'
        b'\xc8\xdc\xcb-\x11\xe5\x81\xc0LS\xfc\xce\xd05\xed\xe6\x04\xd5\x17\xf8\x19]\x9f\x95=*\xfa\x8e\xb3\xbf(\x9fR^\x06\x85\x1b\x8fk\x87\t\x13\xa7pvL\x08\x13\xda\xa6v\xd1\xad\xf1+\x91\xe4\x17\xc3\xb8\x88\x9d|\x82'
        b'\x1a\xdc,\xce\xb8\xe6\xf0x\xde\x93G\x10\xc1\xe3=\xe9\xf9\xe9\xc8\xb7\xfdV\xf1\x95\xf1\x1eT1w\x99\xffc]\xdf\x82\x14\xe1u\x0f\xeeCpw\x8d\xbf{la$\x1e\xd3\xdfJ\x07\xe5\x02\xa2\x15\xfe\x97o\xbe\x98s'
        b'2\xb4\xec\x998\xf3v\x194V\xb3\xe8\x0b\xe0M@\xfe\xe0\xbc\xa1\x16\xc1,j\xf1=mj\x10\xa4\x88r6K\xdc\x91\x88\x84ug\x92\xfcu\x03\xa8\xef\x97t\x03\xe7v\xf7\x9e\xbed\xb2\x92\xa6\xd1\xcdH\x94\x99\x8f'
        b'q\x8d\xafo\x00\xa5\x1a8\x01`\x03\xb7y\xc8\x8cc\x9du.\xbb\x85\x0f\xa5M\x9c1\xfc\x11\xfebz \x9a\xc0\xba[0\x9f\x98\xdf\xbc\x05\xf8\xb0\xa8\x84l[\x9fsk\xee\xdauP`lz\x81~\xbf\x16\xd4m'
        b"'\xbf\x89\xeb\xde\xd1\xb6G\xee\xe9j\xaa\xfdP.G\xcc\xc0\xfbn\x1fvx\xce\x8c\x90\x92\x8b9\x87\x94\xf9\n\x0e \x07@\xf6@\xdf\xc8\x00\r\xdb\xdaV\xd2$\x07\x89\xba\\~\xe3\x97cw\xc5\xb0O\xb2\x94\xe0\xfc"
        b'\x96\x8eq\xc8\xa6\x85\xe4\x1bZ\x1d\xad\xa8S\x04\x9c\xf0\n\x8f\xf4?3,\xbc\xcf\xbc3\x1f\xd0\xb0X\x7f\xb7j\xcf\x99 Mw\x1a|\x0eq\x1c\xa8^\x92DC\x17\x05\x8ci-\x04o\xe7|n\xcd\xed\xb2\x95%\x01'
        b'\xfa\xf3\x8b\x88\x1d\x14\xba\xcd\xe2\xb0\xb4\xce\x99\xf9\x00\x03\xc4\xe6(\x14\x07\xf9#zq\x8a\x89\xd0V\xc8\xd1\x15$\xd3\xe8T\x85\n\xa1\xcc\xbfFh\x97\xe5\x8ey\t{\xb2\x05\xd7>\x1eK\xbf\x0b\x1b(r$(\xe3\xd3'
        b'\xc5\xf8\x8b\x1e\x83`\xd2\x94x\x8c\xe7\xde\xd8z\x10F\x05~1W\xac\x83\xc5I\xa7<\x189\x0cD\xa8\xbb\x98\x04\xce\xb4p\x08\xd0TU\xdd\x9bY\x12\xd6y\xad\xa9\x14\x80\xe8{\x97%E\xfao\xac\xf3\x89J1\xf6'
        b'\x18\xa9$\x84\xe5FI\x06\x13\x87\xc4\xedu\x12\xcfa\xdb\xadx&\xd0\xc3@\x954\xf0\xb1\xe9\x8c8q\x89\xfe\xe9\xda\x00G\xa3\xd6\xd88\xc2b\xc1\xef\xbd\xd4_F\x8a6n\xbbN\x90j\xbb\xbc\x93\xc6\x91r\xce\x90'
        b'\xbf\x84m\x1b I\r;\xc9C\x97\x16^6\xe1\xe0D\x94V\xd0\xf9G\xec\x07.QM\xe3\xb5XV\xc3\x9a\xfd\xa8%\xfe7G\xb0\x1a\xa2\x10\xb4\x91u\xc9\xba\x05<O\xdb\xf0\xc8\xd6\x97\xb6\x00\x9bkg+\x94='
        b"w\xbdlr/\x9d\xe9\xfa\x88\xecm\xb4\xc0\xbf\xbb\xa7x\xf5WfT\x9c\xaa\x16\xa7\x8e\x88\x1c\x11}\x95\xdc3H\x14\xed\xa3x\xc7\xce\x1b\x0b\xd3\xf3C\x91I\x1c\xbe\xb4\xaedc'\t\xc5\xcdS\x97\xd0\xd2n\xff\xe6"
        b'\xa9\x8c\x98\xb9\x856ttM\xca\xd0\x1e[J\xae\x85\x0e\xe0\xc5\xa7\x98\x14\n\xbc\xd4Df\xe5\x944\x93}q\xb5\x04\x8b K?\xf7\xc3\x01\x0f\xaf\x81\x83\x18\x19\x89\xf4\xc4\xac\xf2%{\x8e\xef\xc5/\xa2\xdd\x98|\xf0'
        b'iWMg\x99\x8atW\xb8Y%]\x00\x83g\x01\x0fn\x02?\x01\xbc\x14\xa5\t]D\xd4\xd7R+I\xa9xog\xef\x07\xdd\xeb\x1c\xba\xa2cy&\xa0\xe9\xfb\xc8\xbb\xfeG\xcbG\xf2\xf4\xba.2\xe9\x0cU\x8b'
        b'\xc8,\xe7{T\x02\xdfR\x05a\x8a\x7fBK\xaeh\x18H\xf7\xdc\x9a\xdb\xe73\x8f\xe2c\xfd\xbf\x1f\x0c]\xbc\xd2\xd8H!1\xf5\xa3\x07\xfb3\x12E\xb0\x80\xb6\x11\x0fSI\xd7\xef\x9d\x9b\xb2\xff4\x97\xf1\xd1c\xc9'
        b'\xf8{V\xe4\x8anc#\x19ToR\xb17\r\x84\x90\x9c\xeb\xe3\xf2\xd4B(w\xfa4\x02\x98N\tK\x00\xce\xf2\x1c\x93\xee^M\xbaK\xcf)\xb1\xf9;\x132\xfb)\x8b:\xe7\xf6\x1c\x00C\xb1\xc0\xed~Qr'
        b'?\x93p\x16\xc1\xb9)N\x1b\x89|\x7f@\xc2\x91\xed\x88\xb8+I\x04\x86\xee\xe4\xdc\x11\xc3\x06x\x81\xd4)f\xf0\xcaY\x1a/\xf8\xbf\xf0\xf7\xed\x06\x95\xe8\\b\xb1A\xc3& 1\xd5\xedxsb\xa4\x0f\xf8\x02J'
        b'\xfcBp\x8b\xa2k\x1f4\xf7\xc2$\xf6\xb5\xe5\x0e\xad!P\x85/\xe8\xc6\xb3s\x15\xae\xf8\xd5\xe5\xbbp/ 2$"G\xf7<\xb1\xb4\x87\xe53\x8e1\xb7\xb3k\xf2X\xacx\xa6d\x94\xb6\x9eK\xc1E\xd4\x10~'
        b"\x8ab\x05\r\x8a\x1d\x938\x89\x82\x85E\x81\xe3\xa3\xbc\xe7QM?+E\x1a\xfc\x9e\xdb\xd6W\n\xff\x9f\xd0:\x93\r\xc8\x8dI?'\x87\xd9.\xa2.~\x19odSI\xc4\xf2WW\xd7\xa3\xfb\xc2V\xec4\xbd\xcc"
        b'\xf6B\xe8-/\x8c\x1f\xf3W\xaa\xcac\xd5\xc0^\xed\xe0\xaf\xee\x0b("\xbb\x84\xf1\x0f\xc3;a\xcf/TNqv\xf7\xf3jXN\x97\x1dW\xfdR\xe8\x8c\xa2\xde\xe2\xfd;\x1d\xac\xb8k\x19n\x00v\xcb\xd8q\x1b'
        b'\x16\x823\xb3\xa4\xa0\x96~\x7f\xfe\xb2>[\x17\x1d\xf0\x8f\xc5]>UH\xa5\x99\x91$[\xb0\xc5p\x83`\x94\xc0\x94\t\xe4))\x04\x8e}\x05\xbc\x1dkD\x80\x0e\xa4\xee\xbd\xf1\xd0w\xe7\xd4\xd5\xee\xf9Z\xe1#\x95'
        b'\xa4^\x00\xbbs_c\x05\x96\xe0\xabX6\xa5\x90\x0e\xc5\xfa\xee\xa5%yLE\xf2M\x99\xfc_\x80\x1a\xdao\xfe\xb6g\xb3\xa0\xc49\x1a\x1bF\x04\x07\xb3\xfb6u1H\xccEH\x8e+\x1c\xde\xea\x974\x80J\x17'
        b'\x05&\xcf\xd6\xb1v0\xec\x12g\x8c\x88\r\xf6\x1az\x90\xf6\r\x99#\xb3\x97\xcb[@\xbb\xc6\xf5\xb2\xc6]M\xddG\x8b \x17G\x85\x9fH\x17\xd5\x9b\xab\xf6 J#\x96\r\x84E\xff:\xd7sF\x8f\xe7\xcb\x84T'
        b"\x8eQv4\xbb!\xd3\x91>\xf0\xdf\xa8\xaa\xdd\x89YQ\xa3'\x11\x15\x17|\xb8\xf6\xe1ZD\xfa\xea\n\x85e\xe6\xe0]\x04\x936p';2J\xcb\x1c#:7<|\xcb\xc8\xf9\x9c\x95\xd3\x99\xd7gVr\x0e\xd1"
        b'\xdbD+\xbeF\xdaO*\x8de\x9a\x05U\x85\x13\x9a\xdaH.\xb0\x97E\xd5\x08\xbce\xc6k\xe9\xaa\x96\x12\x00z\xe3\xc3\x0c\x81\x16Y\xcf_\x10\xa1\xe4\x1b\r9\xf7v\xa3f\x98\x0e\xab\xf1\xf6\xa3\x0b\xf6g\x96\x10\x8b'
        b"\x0bO\xa7\xf9\xda\xd5 [\xf7\xf9=\x95\x9e\x02\xf0\xb0Y\x1czJ!\xa2X\x1f}z\x9f/\x11l\x8aN\x87\xf1\xcf\x9fb\xa0'@\xf9\x7f\xea3\xbbj\x1c\x7f\xack\xc7\x8f\x91\xe6q\xb9\x912-\x05\xba\x08%W"
        b' \xe2\x18\xa7\x07\x02%=\xf0\xd1Bb\x92\xdeC\xa0\x8f\x0f\xc4\x1f\x80\xb0\xdb|N\xf0\xb4Y%\xdd@\x0e\x1d\xff\xea\x81\x03\xd8\xc5\xffD\x80\xe7?(\xee\xe9\xbax\xc4\xbd0\xe3=\xb1S\xe1\x9a\x91\xb3\xa6\xfe\xb6\x16'
        b'\xf8\xfa\xc6\x15\xf2Hu\x98\rr\x8cP\x8e\xd9r\xf1\t^\xa9\xc6E4\xda\xd3\xd6+\xae-y\xa0Nq\xe6\xa6\x9b\xfa_S\xa5n\xaf\x17\xb8\xd8\xa2\x82\xed\xabO\xf7\xac\xa0\x80\x10}Y\x0f\xb8\xebX\x07\x8a\xc8\x16'
        b'\xe0GHk\xd5<\xf0\x1a\xab\xe6\xc3\xddD\x0c\xc9Wf\xd9\xce\xe2C\xf8(\xebD\xe72\xfbOR\x05\xf2\x07\xaa{-=\xc3\xbe\xa0XD-*\xd7\xfcX\xfe_\nU\x9c\xce-\xd7\x01\x1d\xfd\x0c\xa9\x1e^\x8a^'
        b'\xa5\x8d\xd0\x85\xd0\x1f\xe4\xc0\xf0\x08\xf5\xd7K`2\xba^Q\x9f\xfe\xa5\x05\x93\xe9\x14\xf2\xf7v0\xc3O\x0e\xea\xd2\xa7m*\xea\xd0\xe7\xc9+\xa6g\xd3\xca\x9a\x1bt!y[\x03\x9e@\xbf\xd9u[&Q\xaa\xd0W'
        b'8[\xe0\x08\xb0\xe3\x17\xc9\xe6^\xcc\xa9\xcd\x19I\xd7h\x86/T\x12\xa1\xcd\xf4"\xe6\xd96\xfe\xc3\x16\x88\xf38T`\x8a\xd9\xc5d\xe9\xacK\xab\xd3N\x0b\x88ca\x84o\xe8\xfaL\x88\x91\x9f\xdd)=\xaf\xb38'
        b'\xc6R\xa2\x9e\x15\xec\xdf\xae\x86\x14\xaf\xbf\xe8\x0c\x16\xe1\x08\xd3IW\x08\xce}k\xa3M\xef\xb0\x15o\x87\x8e\xcf\x8c\xdc\xca\xfb\x02WfL\xb8\xf23GG\xfax\xb6Y\xc7(\xe0\t\xe8\t\x87\xf1)\x1e\xfc\x89\xd3\x06'
        b't\rw\x168TD\xb4\xafa}V\x82O\xb5S\xcfy\xcd,\x97\xfby\xc8\t\xe3z\xd5\x1c&cA~\xbf\x19[xh\x01\xd2Q4\x8e\x1bC\x9a\xd9\xcd!J\x13=\xd2\xfaB\x15\x8a_\x7f!\x02\x14Y\x83'
        b"\x8aQ\x05\x8d\xe1\xfdeH\xbd\xec\x85\x7f\x1c\xde\xb8\x87'\xdc\x01\xca\xf0:\x8fGz\xf9}|\xab\xeb\xa4\x07\x9f\xe6\x1d\xa3\xf9\xac\x11\x1c\x06F\xbb%D1q\xa2U\xccZ.\r\xe4\x10O\xf0\xf7hk\xff\x9dx\x12"
        b'[/K\xe8\xde\x84\xbb\xb6}\x07&\x08p\xcb\xec%L\x85\x01\xb3\x0e*\x17\xb5-\xb9\xc1e\xb3\xe2\xad6\xc8\nWa\xadI\r\xb4\xea\xe0H\xee\x0c3\xb2\xa3\xd1\x84\xf1.\xbb\xaaY\x19\x8c\x9c\x9b\x1f\xfah8\xf4'
        b'\x9d\x0fU\x80\xfa\xfd\x9e\xba\xbclJ4\x82\x04\xc6\xa8\x088\xfd\xb3-\xabS\xbd\x00\x7fi1\x929}\xdc.u\xacA\xb7\x92G\xd8\x14\xf4j\xb6\x17\xcd\x08\x97\xd9\xc6\xb4>3\xaa\xb5\x1c\xf4\xe4\xcc\xbb\x1a\x84\x99A'
        b'\xad\x97\xdd"\x00\x10\x94\x07mYf@|U\xda\xca\xd9`\xcb>V\xf9M\x90v\xa7\x00J4\x97e\xa5\xaa\xaaZ\x91\xcf\xcaIYn\xb2\x92t\xf49v\xf3\x96tmV~r\xa5S\xda_\xf1\x1c\xd2\xe7B6'
        b'\x87E"\x8a<\xbb_\xea\xc8-\xe0\x88@\xa4~J;7\xfef\xc4\xe6\xc2\xa2~\xf6.\xb8\xeb\x94cm\n\x0eQp\x88\x89d\x1dN"b\xb3\xdb\xaf\xf5\xe6\xe6\xc2s\n@<\xc6\xf3?!2\xda\xc3o\x9d*'
        b"\x03UY\x0c\xb4\x9dJ\x8d\xa3?S&7NI!I\xc0*\x8c\x03\x83\xba\xb3\x8bRCn\x07\xab\xd9\xf0t\x00>\xdc\x9f\x0c\xf9\xce\x98\xef\xa7\xd8\xec\x1eg\x1b\xe0\xf1\x90\xee\x18\x1b\x96\x04\xae\xf1\x16'N\xd6\x83\x9c"
        b'\'\x8a\xf4\x81\xb7\xd1\xbeN\x8dmE\x89\xbe<\xcc\xb4B73\xe2\x00o)\xab\xab\x0bI0\xde\xe8S\xfc6\x0b)\x02\x91\xeck\x9c\xdd\xb2\xcd\x03\xb24"\xbd\xfd\xc4"\xe0\x9a\xf6n5\xc6\x9f\x18\xc8K9y\xa6'
        b'\xee\x00\xd4\x1a\x9e\x06l\xa2\x8e\xa5\x1c\x14K\x02\x19R\xd5\n\xa5\xd1\xd7K\xfa\xe02(\xe3H\x0eKkV\x9f\xaf\xe1\x9b\rK\xc1\x96\xbd|\xf7\xf3\xc2\xdb\x89\xcb\xbel\xee\x1b\x03Z\x89XO >\x0fG\x03 !'
        b'5Az\xe7\xae\x87}\x12\xe2\x1f\x0c\xc8\xda\xf9p\x10c\xaf7\x1d\x18\xb9\xb7\x1dt`\xfe\xecB\xccP\xd8I\xe5WE\xd1\xf0b\xdbA/\xb3\xcd\x9e\xb4,j\x9ch\xe0d\xa4\xcd\x1f\x99Ik:6\xfb\xec\x81\xb4'
        b'"v\x97\xb3\xc6%o\xb2H\xbb\x85\x14.E\xb4\xfe4\x98F\xa2\xed5\xe4kN\x0e\x03\x81\xd0\xb9+\xb3\xb3\xbcd\x85>\xb8\xb4^\xee\x05\x85TLV)|\xeb\xda\x93G\x00S\x81g\x06\xf1\x10e\xc7\xf3\x9f\xda'
        b'\x15"\x7fSA\xb0\xaf\x8a\xc6;\x94\x03\x00\xc0M\xe3{\xb0\x8e`G\x16^\x9a\x00\xd1\xa1\x04!\x00"\x05\x04\xdc\xfc\x15l\x9e\xd6\xcbtnN\xb5Q\x87\xad7\xa3c\x03\xc1Y\x13\xb8\x97\xd6\x06u\x7fr\xaf\x1f\xf3'
        b'\x0ej\x90\xc4\x02\xf8\xe1M\xd1(*\xac\xdfP3y\xdaQ,\xa0\xa3\xd5to\x95\xf3\xa0\xc9\xc2\xb4\xbd\x96L\xff\xe3\xa97\xd3\x8bI\xb7~2\x0ep\xff\xb3X\x87TH\xf8=\xde7\xc7\x81\xf6\xafC\x0c\xfe\x1fQ'
        b'\xa2\xfb\xe8\x07\x03\xb0&\xe3\r\xef\xb7\x00t \xeb\xc8\x0b\x85\xf1@\n\x9aN\x83\xe1\xd22o|\xab*\x81\xce\xb5&\xe9\xc9u\xb0\xaaGndN\xd2\r\xa3\xe7\xaf\xe1\xfcin\xdbq\xde\x96Oo\x96\x87\x12\xfe\x10'
        b'"%\x154@\xfdI\xa8c\x8c\x8cl\xee\xd47/\xf1\xb4\xbb\x98eI0J2e\xddR[\xbb\xd2K\xf7\xdd\xe7\xe5)\x7f{\xe78\x18\xb0\xb4Ch\x9f\xbeHBe\x91OuP\x1a\xc44\x12\xb7!\x15h\r'
        b'\xfe\x98%OYa\xbb;\xba\xf3B\xa4\xa8J\xc8G8>D\xb0\xd3K\xed\x04\x9b\x0fp\x03\xb1g^\xa4-=\xf2\x95\xa2&i\xba\x93\x03\xedP?\r#:\xa1\x0e\xd2\xfc\xaeY\xd7[d\xb5\xb1\xd7\x16\x82\x0er'
        b'e\xc8\xa8\xb8\xf9?\xfb\x94\x99\n\x92\xf8\x82\xa3\x96Q\xc8;\xd4\x93\xb0\xf0!\xca^tE\xfc/\xff\x8f\xdb\xbf\xdf\xd7\x97\xbfe\x0f~h\x17k\xc2\xf8\xaeMn\x01\xb8\xb0\xf71\xa5Q\xdfN\xa4\xfdk\xb5`>\x1d'
        b'\x95\xd5p\xaa\xa8\xbb\xfd\x0c\x0c\x19\xba\x81\xd1c\xdaZ\x7f\xbf\xb3\xe1\xf86\xa8?0\x04\xb3\x8e\xf9\xaf713\x8c\x17>o-\xc6\xe9u\xc3P\x82\xe5\x0bY[5\x1c\xd3\xa3t\xd4\x95\x1d\x88%\xe1\xd9~\xaf8\xf5'
        b'\rZ\xb6\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00'
        b'\x00r\x05\x00\x00\x00\xfa\x15<frozen fintech.iban>\xda\x08<module>\x01\x00\x00\x00s\x04\x00\x00\x00\n\x01\x14\x01'
    ))
