
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python FinTech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00z\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x020\x00e\x00e\x02'
        b'e\x03d\x01d\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds2.\x00\x00PYARMOR\x00\x00\x03\t\x00a\r\r'
        b'\n\t4\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\xf2-\x00\x00\x00\x00\x00\x00\x15\xb6\xaau\xac\xaf\x87\xc7#\xd0\x90G\xea\xe9H\xad\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf8\x85'
        b'\x02\xde\xba\xd9\x16\x9aE\xfd\x0b\r\xe2a0\x8e\xc4\xaa?\xd5\x840%\xf2\xf4A\xf8\xbb\x9f\x1bb6\xff\x07\xf2k\x8d&\xda\x7f\\]cA\xa6{\x8aF*\xc5s\x07\x03\x83-\x96\xdb{\x11\xefI\xe82]\x88\x19'
        b"\xdd\x9cS\xe4\xc0#F\xcfqT\x8e\x9a\xa8\x8f\xcb\xfa\x90d\xb7\xfby\xee\xe0\x15:\x1b\xed\xd9\x1f>\xb5\x07\x8e'\xba\xfcT\xee(\xf5\xef\xe7\xf6o\xd6\xbc8\x80\x9c\xa5\x8e.n\xf7\xc2\x89\xdb\xb0\xbb\xa2\xefH\x9b\x00"
        b';\x9c\xdb\xbf\xdeIk\xb7\xd4^\x97\t:\x9b\xaf \x16C\x9b\x9c\xdeP\x886\x92\x18\xcb\x15\x04\xd3k\x87\xa6\x7fb\x9e\xd4B\xaa_\x93\x0e\xd9!\x18<=\xaf[\xa5\xe6~\xea\x0b\x14t\xa7B\xaa\x99\x0b\x00\r|'
        b'\x1467\xb8\xe1\x8a\x0c\xd4\xdc\x92\xf1[\xca\xde\xad0cYc\xc12\xb7\xb2a\xd26oh?\x15\xd3vN\xf2\\\xdf\x19\x81\xf6,\xb8\xa9\xe3\xc7\xb1\xcd\x80\x08(\x87\x85\x0b\xbc\x81\xb6\xd2L\xfe\xd0\xd0\xff\x0e[&'
        b'og*bR\x10\xe4sl\x90\x82\x8b\x00`|*\x9b:\x91w\x1e\x98\xc9\xc8`a\x87\x93\xc9\xa98\x94\xcf\xc4\xf2\xcfH\x84"\xb4\xfe\r\x80\x9b\xb2O\xc1\xaa\x96\x1e`J\xb0\x11\xdf\xb9\xcb\xdf\n\x93\x14\xc3\xca\xc3'
        b'\xa961\xc1\xb2\xfe0\xfe?\xf5\x1f9\xfe\xc87\n!\x96\x92\x0e\xd7\xd1m\xba5\xf9\xbe\x93:z\xa6_8\xc0\xc5\x1f1\x8a\xa4{\x8c\xae\xaa\xf0.x\x01\xc0\xe7W\xe5_\xff\xef\xf0\xde\xf8k\xf9\xeb\x017>\x0c'
        b'\xdfE\x00\xf5\x9blgk\xab\xf2@Q\x0fn\xd8\xb5\n\xd22\x7f\x9e\x08\x801\x9cu\xff\xcb\x96H\xf1\xe1\x1666\xeb/\x15\xd5\x16\x8b\xcd\x84\xf2Uu~Ih\x11\xad\xbe\xe7\x1d\xe1\x0fAA3\x88W=\xec"'
        b'\xdc\x00\xea^\xd9\xc0\x9eg]\xcd\x03\xa1\xd0i\xa7\xe6\xee\xa9\xae\'a"%\x1eY\xde\xd5\x16\xf5e\xad+?\x10\xc1:\x81d\x8a\x85\xf7\xb1\'\x80\xca\xa0\xc0H"\xb6\xe0xk\x8aW\x90\xa1\x11\xb2W0F\xeb3'
        b"?\x94^\x12`S\xdfbs.\xec'\xd6\xf2Q\xf9\\W\xe2\xf8\xc4\xb3\xb9K\x96\xdf\xaadP\xadM\x0f\x1eq\x15\xd7}\xb4\xc3\x16\xd6f8\xcc\x1fvV\x11\x82\xe7qv\x93O~\xed\xefx\xba\xdeM\xfd\xe1M"
        b'MD\xae\xc2\xd2\x96\x01}\xe0\xf2\xc1-\xe36c\xc7F55\x932v\xe8\xc9p\xf6\xadR\xe9^\xd1QJm\xf6\xaa\x7fg\xbd\x93\xcf:"r\xa4e\x9b]\xc7W9\xd9\xfa\xb1\x9e\x89\xf4*\xf2D(\xdb\x08e'
        b'\xb9\xf3b\xd4x]~\x1e\xd0\xeb\xc4c\xe8\x91\x1f\x85\xbf\xd89xd\xe4\x81\xae\xc1"\xcf\xcb-a\xb8b\x18T\x9a\xae\xa4\x02e\xb9?I\xed\xec\xe1B\xe4n\xf3\xc5\rG\xf0\x01\xdb\x8d%I^\x1e\xb0l9+'
        b'\xcd\x99d\x1e{GCn\xd1\xd6\xefj\xebX\xb8\xbc\xec\x01y\x88i\x0fZ\xc6\x87\xf8Q\xc3\xdc\xcfm\x8e\x92Si\x0b\xde`\xbd#\xc1N&\xb4X"\x18\x85\xa7!i{O\xe9([\xc3\x06\xdfT\'\xbd\x05A'
        b'\x14\xef\x8b\x7f\xa8\x97\xc6\x0c\x12\xbdNd\xacy\xef\x86p<\x8a\xf3\xfaB\\\x9d\x16\xe2\xe1\xd5\x03\xe3\xf2[\xa4\x85\xf8\xda\xcc3\xcc|\xac\xcd\xd4\xc7pH\xf7\xab$\xe7P\xf4?j6\xf8\xe2\xfd\x96O\xedC\x13\xba'
        b'[G\xdeY`2\xceX;\x02F\xf6\x81\xee\xea\xed\xdb\xdau\x10\x92/\xac`\x9c^/\x89i\x03\x8d!\x04\xaa\x11\x93\x0c\xe6\xea\xfa\xfa\xfd\xfd\x80\x10\xe6<&~\xd0\xc5W\xc5oE@\xb6\x96\xdf\xd8\xf4\x01mC'
        b'\xac \x8ad\xd9)A\xc8I\x9a\x9c/i\x80\x03\xf5\xa0\xcf\xdf\t<\xd9\xd1B\xd9\x1a\x13\x17\xb3\x1b\x82\x8em\xc4+\x17v\xe9\xbd\x1d3\xad\xf9\xf2\xe8\x84f\x10\xc0\xad\x1b\xee\xb4\xfd\x8e\xeez\xe5-\x07u\\j\xbd'
        b'v2\xdd\x08A\x01W\xb5p\xce\x91\x9e\xb9!\xb1%\xbbic\xd6\x8c\xcblE\x80\xa7\xe3\xcd&\x1ags#\xfe,\xef\xe3\x94\xc9y\x00k\x872\x01\xc0\xfc\xd7\xb6\xdc(\xd9@\xe0\xce\xe22\xaaG\xd7\xc9>\xc9X'
        b"i\xf4t\xfd\xa2\t\xb7k\xb3\xeb\xa5\xc7\xfdO\x95t\xec\x01\x8a\x00k\x913'VQW/\x0c\xf3\xc8Q,j\x05p\x9b\xb9\x12/\x87;4\x0bD\xd4\x8aC\t\x96\x81n\xc3\x8a\xa8\x00I\x06\xec\xc6\x14\xca\xee\x86"
        b'\xbf\x07\xbfw\xe3F\xb4r&\x83\x19[_\x11`r*`F\xc0\x0e\x88\x16F\xf8@\x12#Z\xe9\xc1\xb4\x17#\xf3\xe0\xb0\x84i\xf7\xd6,(<\n\x8d}\xccf\xe4*!9\x07\x06u\x1cs\xcalm"T('
        b'\x96\xb5w\x94\xe8\xbd\x99\xae\x1d\x02\x15\xe8We\x11\x08\xb7\xa7\x9c\x83z\xba\xe4\xc6\xdbW\x02\x8e\x9f\xbdk\xfdlCK\xbd@\xa6\x1d\xc2\xd9\x99\xfb\x97\x93\xc4\xe8\xa7\xa7\x0ff\xc2\xd9.\xb9\xb0\x8d+/\x9c\x97\x1b{\x01'
        b'\xef\xd9R\x9c\xe05G\x18\x17.v\x15\x1c_\xf6\xde\x9eM\xed\xb5G\xd3 \xe5%Y\xd5\t[\xea\xf8\xb0\xc7\xeb\xd4\xf7\xd7:\xeegL\xdc\xfaw\xa9\xc8o!\xf3\xbe\x16\x92do\x19\xc1\xdd\xbe\xe8fe7\t\xfc'
        b'\xc0i\x02\xffOE\xb6Q\xb3w\x9e\x8f\xbe&~m;V\xf2a\xc6_\xde\xa5]r\xc4o#*U\x8c\xcb0\xb2/\xc6T& u\xeb\xfe>G\x98\xd9A}\xc2\x9coM\rH\x03 5\xb8E<K\to'
        b'\xbb\xf7\x94[u\x08$\xfc\x05\x9fh\xc9\xa9\x8e\xf7&\x14;\xa6\xf3\xa0\xfa\xd2\xdf}\xb0\xba\x96\x04\xf7\xd4\xd2)\x00`\x06 x\x14\x02\xe2\x15\xe5\x9c&\xb3nH"\xd7\xa0\x0ep\xe9\xfb\xdc?\xd5\xc5\xc6y\xc2\xaf\xc9'
        b'\xea\xe5\xdc\xcc\x18M\xb9\xf3\xe1\xa1\x06\x9d\xbdP\xc1e\xdd,\xb3\xbe\xe1W\xc8\x9b\xa1ge\xa7cU\x9e\xdf\x11zyu\x18 \x04\x9f\x8bv\xa1\xbb\x03l6\xc4\x12\x99k\x05)j\xb0\xf6\xa7\xe0;{\xef\xc9\x15\x90'
        b'V\x9b\xf9\x19\x86\x02|\x8b\x92\xba]\x86\x84\x1dp\x88\xbc\xa6\x96R\xac7y\x93\x0b\x19\x8e\x05\x0e1-\x91\x99+\xbb_aH\x9e\x85\x8eB\x8b@S\xd5\x01\xfaVV\x80\xef\x15H}\xf2\xfc\xbb\xff\xb1UN\xb1a'
        b'%\x11R\tW\xfa\x98"E\xbfN\xf0\xe6\xd4>\xc0\x03x\x84\xb0o\x8b+\xf3\xbd\xe0\xcc!\xb9|{9\x88\xccc\x03\x86\xc6`\xb6\x19\x86\x06\xf7E3X/\xf3\xb6^)\xb7\x83:N\xf8 \x9f\x92\xb4;q\xa6'
        b"\xef\xc7\xfc+\x023q\x84a\x0fR\\w\xa2\x07'\xfd\x82\xbdA\x93\x0b\xf6iQ\x99\xe3\xcf\xf1\xd1}\xb9{f\x1b\x0cx\xef\xa88\xd4\x99w\xf5\xd1^\x96$mg6&\xf6\x9a\xf2\x1b\xf3<<Kpu\x01\x06"
        b'\xac\xa1\x7f-\n\xc1\xaa\xa7\xf6oQoc\\Y\x95\xf6\x98i\xcc\xcc\xd6:\xd6\xbdl\x80s\xe2a\xc4\xaezU+<<O\xa1\x87\x92\xc0\xfe@\xf3\x0e{F\xc7\xfc]s\x06B\x96\xdc\x03\x88\x805\r\xe6$h'
        b"a\x0b\xd7\xba\xa6C+\x91\x02u@\t\xd9\xb7\x88\x80\x90\xc7\xe9GU\\\x00\xf8W\x9aXv{z\x9c\x18\x8f\xfe\x0f\xa8\x88H\xd5da\xf8\x19\x00g\x8ar\x8f\xad'u\x80\x19`\xa4\x985T\xb0\xf1/\xf0\xa3w"
        b'=\x8fL\r\x1d,\xba(\xb1\xe8)\xc8\x13\x10\x90Q\x9e\xf7\xc0\x88\x8aEC\x9bJ\xabN\x11s\xd2\xfb\xf8Q\xbb\x7f\xbe8S\xf5\x81\xc7H\xbd\xff\xc0K\xeb\x8dL}o\xad\xd1\x07e\x86\xc2\xa5\xed\xe8w !\x84'
        b'\x80\xc7q~\xc4.-/F\n1\x9e\xa3\xfb[\x8f\xf0\xf0\xa2\xcd\xb7\xf6\xb0y\xd5\xbe\xaa0\x8c%\xff\x0f\x06\xfbi~\xc6v.\x0bR\x1f\x9b\x8e\x9f\xba\x7f\xadK\x02\x164A\x8f\xa7$P_.&\x94\xba\xd2\xee'
        b"\xcc}\xdd\x10NS\xe2\xd7\xc7\xfa\xce\xe1SY\xc0\xc7C\x92\xfd'0\x07ag\xd1\x1e,`\x9a\x9e\xa8stKS\xf3\x12\xc7R\xfb\x0b\x0b\xad\x9b\xac\x88\x0e%\xe8\x8a\xd9\xc5=l\xe6\x1b\x95\t\x80\xb0\xf6\x88\x08\xe0"
        b"\x96s\xe8\x8f\xe3#B\x1arnw\xac\xc2\xea\xbfY\xc6\xca\xdb\xe9\xe2\x84\xa8\xf8\xc4\xf9\xbf?\x84ke,\xc2\xa4\xa6$[Y\x17\x94\x98\x80\x06\xe7\xc8\t&[\x94\x9e\xfe\x04A\x19\xa4\xeaA\xebT\x1ai'\xeb%"
        b'o6\x01\x81j~\x98\x01\x0b\xda\xe1rMqPl9:{z%\x10\xba\xbb\xfa\xae0Z\xa0\xf0\xbe\xddK\xaf\xaf\xe1\x0et\xe5\x95>l\x19\x94d\xa4\xdb>\xba\xe3V\nn \xef3D \x80\x02pk/\x81'
        b'"\x9d\xeck\x17\xda\x13\xe8u\x11\x82\x83\xa4\x8a[\xb8\xe8\xb1\xd1\xf9\xc3^\x1c/W~\xf4\xf7\xbc\x8e\x89\x04\x04\xb2\xb3J\xdf\x99@g\x97\xa9\xc9g\xbc\x0fd\x80\x8e\x1cj\xce\x9b\x93~[\x83\xfdI\\1\x87U\xdc'
        b'\xc2\xcb\x92dh#\x05,Gc\xf5\xd9\x97\x9c\x82u\xb8\xab\x0c\x0b\x93\x05\xda\xc8p\xf9\x94\x94\xe1P;m9\xe2r\x94h\xa3\xfb\x08.D\x84\xe2\xdd-\x02Pq\xc2U=\xf09v\xecZ\x84\x88\x7f G\x08\xf7'
        b'\xbf\xc3\r\x08t\xf3L\xeb\xd9&\\\xcaOf\'\x81\xcf\xc3nk\xa2\xd8\xcd\x00\x12\xeb|O\xda\x97\r\x80H\xe0\x9d\xa7"\x0c\xa7\x8d^\x13\xc9\xd1\xa7\x86\xad`/\x01T\xf8Et\xe9\xa6\x8a\xc5\x86>i\xaa2{'
        b'\xc6\x85\x94\x85x\x08\x05\x0f\xe0N#n\xad\x9e_`\xfe\x8e\x85\r37\x9f}\xdd&\xd2\xf9\x9f\xdby\x16\x1aS\x14Jy[\xaew\x98\x16?\x7f\xb6/=\xeb\xdf\x1c\xab\xff\x9b\xc0m\xccd\xb1\xce+\x82\tj\x13'
        b'\xc5\xcc\xe3#\x9b\xaa\xe2G\xa6\xe6J\xcb\xd8_\x84\xcc\xab\x15*Or\xcc(\x1b\xe8R\x88\xfaD\x85dZf\x8c\xdb\xcf\xf2\xb6\xa4\xf6\n\xc3#\xae$#g\xad\xa7g\xa3\xe9L\r\x88k\xab\x1f>\x1fi\x97\xf5\xc5'
        b'tBl\xd0\x9b\xfe\x184g\xed\xa3Z\x04\xa4D\xfc\xbb\xf6\xa2\x14\\\xed\xaa\x12\x82\xbb\\\r\xb0$?\xb2\x9a\x06\x96\\\x8eUV\x9cd\xa3p\xbc\xc1\xd6\xac&\x8e\xcf\xb6!\x03\xe7xC\x88=D\xe6\xd3\xb5\xd0\x93'
        b'\xd9S\x95\xd5\xc3!\xf2Zk\xc4k\x85\x921\x82\xe0\xe5B\xf8z\xd8\x97X\x18\xa1\x92d\t\x7f-\xfc\xb4\xba\x19\xff\xd0\xf6U\xaeT\xa0a\xd3\\\x1eA4,\xa9&\x16\xac\xec \xc9\xcb\xd0l(\xcd]\xb1!o'
        b'W\xa5B\xd4\xe7#\xe0\xaaO_[\xa77#\xc9\x04\xb7\x17Qld\xc5\x85\xc1\x86^\xcf -\nC\x9c\xe5E\x9eL\xe7Z\x87"\x99\x04\x1d\x1c\xe2q\x14\xa9\xa5\x99r\x1f\xa3\xf9\x8a5\xf6\xbe\xce\xaa\r\xec\xfb<'
        b'\xca\xc6Ad\xdei\xd3\x94\xd5\x8b\xfb\x87\xd2\xb5u\xa6\r\xf4m\xf1\x96\x00\x8a\xc3y~\xe6\xed\xc9\x0c^\\\x99\x8c\xd7\xaf\xc6\xd1[d2\x89\xc8\xb5\x14\xd8iT\x96\x14^V\x1a`\x80\x8f\x9d\xe9\xb8\xa4\xde\xa5I\xa4'
        b'\x08\x94$\xacgtF\xbd\xfb0\xff\xf7\x7f\x06\xe2\xe0\xceE\xb7\x01\x04~\x0e\xfb\xa8(\xe8a\x95\xdbG\xd1\xd6\xb3r\x16\x17\xc8}q\xdd\xf9\xb0\xc2\x11A\xef\x9flL\xef!\x86\xa9\xca@TE\x8f=\xfdY\x06\xb4'
        b'\xca\xdb]\xc6\xbe\xc9\x90G\x05\xea\x84\x00\x1b\xdbT\x02h\xfa\xe9X\x8eNr\x88\rrh\x9bP\xcc\xfc3\xc72\xd1\xb2\x13\x90A\xc9\xf2\x03\x9c\xd6"\xfd\xc1\xf6l\xad\x84\x98\\\x00\xbf\xe8$\x96\xf0x\xb3\x1ed8'
        b'M\x02j\x94\xd6\x90&0\xa6\xe7j\x9c\xd8\xcf\x19\xf7K\x80\xff\xa0\xabm,\xe30\xa1\xc7\x94\xcfw<\xe1\x1d`RDr\x84\xde\x95\xaf\x16\xed\x1a\xa1 7\xb5J\xba,\x18Cs\xa5\xca\xb4@\xa2K\xb1j\x0e\xa8'
        b'p2\x03\xc2\x9cG\xbe\xd5\xfb2\x81\xb2 \x10,`W\x1c\xb2\xf7H\x82\xe3\x85\x01\x98\xf7D]\x83\x16\xc4\xb7\x03\xd2Z\xcb\xf9\x0cD\x17\xa6J\xf3\xa5\x88n\xd8\xf4`\x11U\xae:\xe0N\xbca\x18\x9aE\xe3\x8f\xe0'
        b'\xff\x96Qu\x1a\x02\x00M\x18\x86\x1e\xec\x82\x91\x00\x10\x8e\xf5\xda\xe5DkN`n\x03q\xe3\xe3)\xaf\xa2\xb7\x1c\\(\xd3\x08\xaf\xc7w\xf7\xa4\xe99\xf6\xfc\x99\x1e\t\x95\xf2W\xd1\xfa\xe3\xbe\x83\xb1\xc8X\x8a]h'
        b'o\x19{+\x1d$^\x00\x16\xb1\xab\xbf\xd2\xae\t\x1f\x059\'\xbb)?j\xe5u`\x15\xae\x03<p9\x7fR\x03\xf2\\@\xbd\xef|\x13\xf2\x1c$\xd2\x89\xd78\xac\x82 k\xaa\x00\x0f\x93i"\xa9\xd0@\xc1r'
        b'7u\xfd+\xc0\xaa\x86\xf0\x99\xf6\x04\xb0\x84\xcc\xfa\xc6\xc5\xbaG\xb8\xa8\x9e\x08\xfe:\xe7\x88\x14\xfc\xfc\xb3\xe6\xe8\x024\x02\xa3\xdb"\xe5\xb4i\xd6n\x12AG\x0b\x92\x9b\x91\x0b\xee\xc1\x15\xc6\xd6)\xc3[V\xfa{\xe2'
        b'X\r\x07j\xf2\x91\x16\x0e`p\xa0\xc3r\xc5S(\xd0r\x81\x8bo\x14\r\xa6\xb6\x0c\x07\xba\xe8\x82\xd3x@\x0c\xd4\xecY\xfd\xef\xac\xf3\x88\xc4&\xf0\xbfa\x92\xacM\xa1&\x1b\xf6\x98\xa4\xa1\xd4\xfd\xde\xda)g\xbd'
        b'7\xd8\x08\xfb\xeda\xfb~\x0f\xc7I\x90\xb5\x92\x08T\x02\xcb\xea\xcb\xd6\x91\x81(\xc9~5\xf0K*V\xc5\xfc\x1c<\xdd#\xb9Z\x06\xbe\x9f\xc9\x01X\xe1\x9a\xd6\x8b\x14\x92\xd5\xde\x16\x83\xe1X\xd5\x84d\x1f\xcb>\xd2'
        b'\x98\x07\xacF\x8e\xc9t\xe5\x1f\x86\xcd\xf6\xdf\x1bf\xed\xc3\x1bs\x888\xb2\x13L\x89\x08F1^\x84\xdc\x0f\xaa\xb4o/j\x9c\x99"\x8c\xb7\t\xe6t\x8c\xf1\xa8^\xf9\x8d^J\xc4%t\x0cT\n\x97\xdc\xa2\xab\xdb'
        b'\x0ejVw\xcd\x113\x02\xfe\x8f\xe1\x15}&\xb6po2~`\xda?z\xbe*\xc6t\x837\x1c/\x1ci\x86\x85x|\x13 \x86\xc69\xc3/\xb3\xf7\xc3\xaa+\xbbB\ro\x06\xee\xdbtj\x06\x02\x11NSW'
        b'\x8c\x8b\x10\xe1\xf3\xc5\x95\n\xa5{&\xb0g\xa8\xba\xda){\xb3g\xee\xb7\xcfg\x81$\xd8-\x81\x92{\xce\x11\x14I\x8f\x05E\xfdM\x15\x18\xfd\xc4\xf3S:\xee+\rvk\xbb\xf7\x7fx\x9d\xc1\x13\x9a\x88\x99\x0e\x17'
        b'4\xb4\xa3\xfa0\x0c\x92\xfa\xb6\xfe\xf0\xb3\xde\xfc\x8e\x0eO\xe6!\xd7\xc8\x18;\xf1k\xcc\xa32\xd1u\x9ci\x1b>\x1d\xd5\xb4\xf4\xce\xf1\xa3t<!\xa7\xe9\x05w\xba\x89\xf8\xe2\xeb\x01!\x8cIM\x82#\xeb\xe6\xe22'
        b'N>\x04\x93\x18!d\xa6\x11\xc3\xff\x0e\xadE\xb9~\xf6\xa8b=\x90\x16\x99H\xde\xb5\xa0\x19G\x0fP%\x07\xe0\xd9\xb8h\x17?\x91)\x92\xdc\xdb8\xf9K\xf1\xff\xf2Q\x18\x99P\x066h\xe3\xfa\xcf\xab\xf04\xb8'
        b'Au\xc1\xb3+\xb6\x94\xd8<\xa81?\xbe-h&J\xe6\x02\xb2\xd0\xa6\x7f\xa7"dxP\xe7%\xa8\xcf\xe8\xc9\xf7\xe3\x0b*\x87F\xc8\x8as\xe6\xfd\xd6Y\xce\xd9\x1d\x0e\xc4#\xc2c;X6\xe7^/S+\xc6'
        b'B\x1f\xf2\x06_p\xb4\xec\x98\x8br<\xab\xbd\x8b\xce\x04"\x12\xe9\x0c\x91\x07\xdav\xa5p\x13\xbd\x19\r\xb3n\xf2\xe6\x89\xcb\xde\r6e\xa4A"\xc5EZ\x89\x9fU#\x7f\xab\x8b6\xb1\xce\xe7\xe3~"\xfeI\xed'
        b'\xf2\xef\xa9`\xb7\xa5q}[\xd7\xc56I\xc6\xa5CX\x96\x06\xd1\xb9\xf8\xf5%k\xb2\xc5W{\x0b\xba"\xea\xf0\x88r#\x1c\xb3\x03}\xc7\xab\xf8s"n\xb8e3\xf5\x9bG~|9\x83\xe4\xfbYc\xbeM~'
        b'\xb4I\x02\x7f\x91|"\xc0\xa3h\\1\xde1\xea\x82\x13O\x9a\xb9\x01Z\x10\xaa\xc1\xd8\xf5\xb3\x96\x17\xd9E\x80\xae"\xba\xc8\xd2\xb0\xc0E\xd1\xf9=\x98w\x9d\xdd\xe8\xf2\x86\xe3\n\xffg\xdc\xcd#\xf3\x8cQ\x0e\x1f\x15'
        b"\x7f*gc\xc9'\x06\xcb\xda%\xe3\x8b\x99ju\xa6\xb9\xdet\xa0\xae\xd5\xdam\xf3R\xefG\x9f\xf5\xb0\xe4`V\x18\xafk\xa0\xc5\xe2\x92#\xae\xba\x9a\xec\xa1\xedO\xa5\x0c\x81~y0Ww}\x0c\xd4\xa8\xcf\xf6\x97"
        b'\x05?\x8ct\xa1\xff3\xe8\xcd\xc6=\xbc\xae~?\x1fn\x1c\xed\xf5\xab\x1a\x0f\xeb\x10\xd6\xae\x17a\x03\x8a\xb0\xd4\x9f\x8bD\x84\xc3O\x93\xc1Y\xf7\x8f\x85\xbf\xb4W\xe5\xc0)\xbe\xdfO\\x\r\x87\xd9\x02\x08e\xaf\x9e'
        b"6\xe9\xf5\x84\x84H\x1d\x9e\xa2\x8d\xd9\xd8\xd6\x80\x7f\xe0\xd7_\xccZQpWF\xce(\xeb\xce5\x19\x9d\x00y\xf4L}\xa9j\xa6wR]4\xa0\xd7\xac\x98J\n\x8e\x1d\x17\xd5\x02'\xe5w\xab\xfa3\rB/\xc5"
        b'j\x9d\x85\xa44\xea\xd1\xaa\x86\xd04I\xf9a\xa3\xf6\xedO`\xac$\x89Ier\x8e\r\x8e\x15\x93,\x15#o\xb0Vq1@`\x8ao\xc96\xfekBK\x84\xb34\xb1{\x07\xce[\x96\xfe}t\xc3d\x7fK'
        b',nP\x7f\xb9i\x90v\'\x17\xb0lL\xf3\xb9\x18\x1c\xeb"j\xec\x99\x90\x9a\xad\xd9\xbaDv}c_\x0b+\xf5\x91\xba\xcdq\x96\x11\xe7\x1b\x12vi\xbc\t\xba\xd4,\x13\x82\xaf\xd0\x9b\x07\x05M\xa8\xae?$\x7f'
        b'\xf7\xe1\xb6\xf2\xcbD4c@2vDA\x12\xf8"\x92\xfbC\xd1\x97\xa2\xcd@\xfd\x93hR\xaa\xd0\xc9\x1aH\xf6\x97\x05\xb0\x0f\xa9\x0fu\x8aR\xeb\xaf\xe9\x98\xe7\xc0\xbaL\xbb\xb1M\xe8P\xb7e\xbe#\xca\xdb\xceG'
        b'\x0c\xd9XO\xc4\x12\x15\xe9EL\x0e\xf0\x8b \xf1\xcf\xeb\xf6PV\x06;\xacf\x04\x06[\xbc\xdd\xa7\x1a\xf6g\xb1\xbe<\xb0\x1cI\x98;\xfe_\x12\xbe<\xb4\xc1=\x84\x87\\\x83%\xaa\xa8\xa9\x8a\xbef\x91F\x9c\r'
        b'+\xcf.LSU|\xd6\x03U\x0cII*\xa8\x05G???\x10\x06\x06\x9c\xd8<\xfbT\x84\x9dLi\x87\x9b\xc99M\xf8\xe2\r\x81\xa5\xb0B\x05\x93\xebhH\x01\xb7\xa8\xe8\x9b\xa0\xf6\xb2\xe2\t\x91\x85"(\xb4'
        b"b\xc9\x87f\xc2\xcd\x90\xc5\xc71C<zMY<\xbf\xf6\x9dR\x97\x9a\x1f'9)\x992ep\x8e\xe9\x16\xbe\xe5\xea\xe0\x00s\x18\xa1\xb9B\xb7>\x97pv\x1d\xfb\x97j\x1fd\x99\xe1\x0f9\xd94\t \x9a\x96"
        b'\x7f\xebJ\xd3\xdc\xa2\xa2\xc5\x90?+\xcd\xe3\n\xd5\xba\x1e\x94\xd7[=\xcb\xae\xfc\rfE\xf0PeT\\l\x1e\x82k\x03O\xcf\xe3\xd2\xb71\x06\xbc\x01\x13\xc5\x130&Y\x9e\xf5\xa1\xc0I4c\xe1\xb9\xba\r\xed'
        b'\xaa\xd7\xbf\x1d3\xb2\xb7\x85\xb7q\x15l\xceA\x149\x8aj\x02\x9eL^E\x8f;e\xd0\xa9\xcd\xd1\xe3\x88\xbb*\xa6{&\x028j\xaf\xa0\xcbVo)/\xc9\xde\x11\xe2\xa45.9hl\xe2\x95\x134\xce\x85\x8f'
        b'+\xba\x0e\x1e\xb1\xeeJ\x07\xb8e\x9a\x8b\x8e\x801\x07\xec\xef\xd2a[\x90\xbf\x96sV\xa6\xcd2cb\xe3(I\x8f\xb4\x02@\xff\xa1B\xd5\xa8\xb8O\x8d\x1f+\x8a\xba\x95\x93,\xb6\x82\xa1<\xd0\x8e\xcd\x9cA\xd9\x06'
        b"\x12\x88\x9f\xf7\xed\xa4\x8cV\xb6\x87\xbe\x8a\x91\xdc\xda'\xfa\x8f\xb3E\xfd\xb0\xa0\\\xd6\xac5q\x05\x84V\x9e\x9aY\xb8>\x19'\xe7;\xfa5W\x99VZ\xc1\xca\x1c\x1b\xa9\x1bzNX\xb2Q\xa9\xc0\xd1\xeda(\x01"
        b'p\xe2\x02F\xff\x1b\x9c\x93\xaa\x03\xe4\xec\x91`~\xe3Q\xf0\xd0\x1e.\xf63-\xfc\xb4\xb2n\xdd\xc7\xb3\xc9=\xfa\xc1\xdf1&_F=f:wKw\xf9\xda0\x11\xc3!1u:"jX\x9e<!u\xcb]'
        b'\xb31\x0fz\xf6\xaaAR\xf2|\xed\xf2\x0c\xae\xf7\xdd\xe8\x14E\xe3{y\xfe\x1e\xe0\xbc\x10\x80g\xbe\x96\xc2T\xcd\xafN\xcc\x86\xf7W\xc9\x00\x92r.\xef\xf9\xb6\xba\x84~:\xf9\x16d\xb0\x12\x025\x1f>\xa3\xa7\xe8'
        b'\x18\xe5\xf4\x17&\x86\xb1>\n0\x18`LJ\x84\xf0\xf7\xe9\xf1<\xe8\xe3\x8e6\xac\xbf~y\x91L\x03\x82 \x9a\xcfc\xad\xdc\x03\xfc\x89UC<Z\xef\xdb\x0b\xeeb\xc0<,\x98\xac\xa3\x8aY\x1c\xd1\xbd\xdeHr'
        b"o'\xaf1\xafz\xb0:?$,c\xc9\x19\xee*\xf5\xe0\xf3\x8fll\x87D\x0b\xdc\xbd\xd9\x85W\x91N\xb4\xdd\xe51\xab\x92D\\\xe7\x0b\xa72\xd3\xb5\xe1\x18%\xbf95\x9c\xb4T\xa4\x88\xe8L!\x04I\xfe\xa3"
        b'\xc8\xa2g7b3\x02)\xa2\x82R\x05\xda\x9e\xb0\x8d/kk\xaf\xb7\x81\xb8\x92mgC\x8c\xdb\x99M)\x08\xdd\xb6*\xff=\xf1\x88\xb8\x0b\xb0\x9e\x8bF?C\xadq7\xd7>DUz{\xea\x7f\xc2~\xecd\xce'
        b'~\xf5d\x84\x13\x0f+o\r 68\x116\x92\xf7\x0c\xebd\x8aW\x82E@\x15\xe6\xa5\x8b~\xae\xe6!!`T\xf86\x98\x0c9\xfa\x9c2\xbe\xe7\xef\xb3\x16\xef\xc3\xb8\xf2\xe8.C\xbe%l\x8b\xc9\xbc\x9bZ\xde'
        b'\x90H\xae\xd4\x14\xa9\xc0V\x04N\x87\xd6\x07,"#\xbf\x06\x1b\xd9D\x19\xeb[\x7f98\x02\xd0\x04bx\xd8\xc5\xe3\xa8<\x89\x0b\x18\xe5_%\xb4SE0\xd9v\x0b\xb2`A\xb9\xd9\x80b\xb08\\\xaf\x83\xe6x'
        b"\x8cP\xd0Z-\x14\xa8\xdf\xc8k\xa8\x01@5\xb1\xa9\x9f\xff\xcfq\xe8D6\xc4\x90\xcd\x9f\xf4\x88^\xda\xdd \r \x1f\x08e'\xf4D\xf52vT\x06\xdc\xb17\xec\tly\x9c\xaf\x11o_\xf0\xe7\xab\xd0-d"
        b't\xbawT\xc10(\x84\x01\xa1\xfe\x1e\x96\xc2\xf4\xb1\xd9\x9d\xf2\xc0\r\x8dX:\xc2{\xfc3\xd0z\xda\xd9\xad\xb9\x9c\xbf\xd3O\x9f^GH$\xc9\xd7\xcb\xab\xa1\xf1\x15F\xe0\x13[\xd5E$N\xe8Z\xf7\x18\xb7\xf0'
        b'\xb5H\x8a\x0bi\xe8r\xf0\xf06_\x01\xcd\xde\x1c,U\xddH\xac#\xa3\x9f1!\x83\xf5\xaa\xa8W\x8a\xba\xa46\x19\xa1ME\xd0\xf9\x828r\xd6\x0c\xe6\x0b\x99\xde\xb8\xb6\xa2\xb1\x18\xe6\x08\xbd\xc4#\x0e\xc1\x9d\x8dL'
        b'%F\x18\xea\xac\x84\x9eu\x00\xcc\x9e^)\x0f\x11\xbc\xb2l\x7f\xc7\xf6\x16\x1b\xb3Or\x8e\xad\xdfuq\x1c\x9dd:\x84\x14\xc6\xeb\xd2\x95\x16w?\xfb\xcb\xd7\x1b,\xcc{\xbc\x98,\xbfI\xd0\x9a\xb2\x07\xe9`\xda\xba'
        b't\xb9\x8f_\xa4\x1d\xe2A\xc7rw\xc0b\xb3o 0\x8c\xf4\x12pl\x89\x8d\x0fA\xbd6\x19 \xad\xa8\xf7B\xda\xb5\x1esL\xbb\xe2^\xf7\\_s\xf9\xf0\x93\x84%}c\xf8~\xe2K\xea\x97\xeaC.\n9'
        b"\\q\xa3N\x08\xda\x12q\xd8\x12\r\x1c\xbc\x06\xe1\xc0\x9b\x16\x1b\xd6\x96\xd6\xaa\xc5d\xc4\xa0b\x95^\xed\x0269s}\x95q]\xb3.\x88\x89\xdai\xbd\xbd\xfeG\xf1\x84o\xf7\x9e\xfa'\x9dZ\xab\xb1\xfa\xfad\xdf"
        b'\xc6\xd0\xa4\xd1?.(+_y\x1dd\x8b\x1da\xf3\x0b%\xee*o\x8e[\xab\xa6\x87~\xd1DnG\xc00\x7f|w8%\x0e\xbe\x86)i$\xf8j\xf2\xf2\x91\x97,b\xd7v=\xb5\x9e\x03\xe3K;=\xe9b'
        b'\x17\xc4\xdf\x1a\xb0\xee\xa1\rx\xfbE_\x16HO\xe8\xd2\xfc\xd8\xc2\x1c\x9d\xf0Y\x8dp\xc6\x83[,,{\xb2\x17~Dw\xd1j\x028\xf8\x81Z\'\xf9\n\x93\xe1\xbe&\xfb"\x99,%\xd0*\xc5\xe6Y]\x9f\x19'
        b"pG\xcc\x05\xb7\xf8\xa9H\x05\xf4\xf9\xd8\x82A\xc0TVe\xd8\xd9/\xec:_ou\xdbP \x9e8\x97\xcb7'\x8a9G\x01\xcc\xd5\xf4#\x17\xba\xa9\x10\xe7\xfb\x95a\x8fJ\x84c\xe0\x13P\xcd\xd1\x05\xf3\xa1\xe3"
        b'|pd\xfb\xf3\xa8(\xa0\xc5\xdc\x05m\x17x\x18\xe7<\xba\xa7\xea\x8b\xd1\x88Q\x8b5\x83N\xe9Q\x10\xfe\x0f\xd7P\xbb/&\xf0\xfb\x0f>]\xfcB2,\x87\x95\xa92\x9e\xaf\xf1:j\x9f\x0e{\xb3IHr\xe1'
        b"\xd0=\xa0\xaa\x891\x08\x19\x82S\x07\x11\xe0\x97\xd1zHH$\xb8\xad-\xc6@&\x08\xf6\xdd\x9cmQ\xc5\xb8x@\x15\x9d\xa4Y\xebjP:u\xdd'.4\x95\xd4\x8eO\xdd\x8a\xe8n2\xac~\xdfYl\x19\x9d"
        b'\xda]\xf3\xbb\xff\xe5\xd6\x98\xfc\xb1\x89sF\xf5\x81\x85\x97\xae\xd4\xbd=\xcbZn\x13b\xf8\xd7\xa6Z\x9a\x1d\xe5J:{x\x9e\xa4\xfd\x1bg\xeb\xe1Y>\xcb\x1d\x8ec\xf9\xa9\xfcd\xd9\x03\xa8.\x96\x85\xca\xf3\xbb\xfc'
        b'e\xb0hE\x9e\xc4\xca\x9dio\xa3\x0c\xee\\B\xe4\x8a\xe8w\xfc8I^\xa3\xebC\x8f\xfcwNB\xdb\x95\xfc \xd6\x08\x8f\xb2\xb2\xc3\xbb|\xb6\xd4}G\xd6p#\x1a\xddR\xf8\xd8\xf1x5\xa0\xea\xdf\xe9MB'
        b"\x12F\x02\x06\xa8y \xf3N\xcdw\xa9'\x14\x91!mx\x97a\xfaY\x86\xc1\xaf\xa2]\xedn\xf0L\x15\xf0\x82d\xe0\x1c\xe0[R\x96\x9c\xfe\xd6yY\x91\x8fT1\x0f{1#{\xc9\xa7\xae\x94\xe4k\x99\x96\xd2"
        b'N\x16\xe3\xa3s\xd063\xfb\r%X\xeb\xfd\xfdN[\xdcU\x88\x0cQ\x06Zk\x8b\x91xkI"\xdb\xd3\xe9\xc8\xe2%\xcef\xd4L\x8b\xac\xd9\x8b{\x9a\xda\x06\xd9L\xa7\xd5%\xde4\x05]\x90\xc3\x06E\x87\xf0'
        b'\xe6\xc1\xe4X\xcc\xf8\xe0\xd0\xac\x9c\x9e%\x98G\xbex\xb5\xcd\xc2\xd2\xd0@~\xdc\xd8 \x8e\xbf\x13\xd2<\x02Z"\xbeL\xb9I\x08\x9e\x1b\x9b\x8c\x80\x0c\x87\x036\x1d&\x11\' \xb0\x05\xd8N\x91\xc9\xc8c7\xf0\xbe'
        b'\xff\x9ft0<:\xc9\xb4\x14w%\xa4E\x06k~\x8f\xdc\x89\x11.\xce\xb1\xa8yW\xa7H\xb7\xe5[\x04\xc0;w)J\xfe\xec\xf2\xd7\xf6\x02\xd7C\xff\xda\xf26n\x8d\x88\xf7-\xcde\xc5\xbc\x9e\x04\x04\x05\xca\xf2'
        b'3\x14\xdfY\x17\x13\xe2\x9f\x8b&\x81Os\x14\x0e\x05\xf2\xd8\xaek\x12<\x045\xee\x98\ri\xb5.\x98\xfd\x15<~\xa9\xee\xe2`\xbf\x15\x89\xa91\xdb\xe5\x97\xdc@\x8d\xb5\x1f\x11\xb1\xd3\x90\\\x82\x7f&\xd6e\xaa\xff'
        b'\x1cu\xa4\xe0\xd2Y\xf9\xd0\x9b\xedf^\x8e\xb4Lt\x85~e\x92\xee\xca&\n\xeb\x9f\xab\xb5\xc9>?-\x9ay\xfe2\xec\xadR\xddI\xf9\xda\xd9\x08\xa2H\xaa\xcf4\xd8\x00\xff\xfc\xff\xcd\x97\x06\xed\t\x17\xa4\x94\xed'
        b"\x06\xc3\\h\xe8\r\xde\x1e\xdc\xa6\xbe\xaa6\x8eW\x13\x93E\x15\x01\x8bn\xdfW\xbe\xc5\x02\xc4[N'p>\xc0,U\xde-\r\x86&\x9e\xbb\x9d{$\x96\x19o\xeca:\xd3\xfd\xe5R\xe7\n\x8d\x81\xca#\xd3\xdd"
        b'\xfe\xd9\x88#m\xbeN\x97\x80R\x0fW\x12}Y\x87\xcdP\xca\x04\xafL\xeb\xd0\xfd\xeah\xb1\x82\xad\x9e\x02\x0c\xc9\xf1\xfaP\x17\xdcB\x9f6\xce\xc2\xbc\x14\x83\xa3\xedW\xa7\x80B-VW\x96K[\xed\xaep&X'
        b"\xfa\xd4d^\xdd\xb7\x03\xd5cv\xf2oP\xd0=3\xb7A\x06S\x9c\xf6\x05\xf1\x06>\x93I\xe7\xc2fE\xc4\xff\xb50R\xe7\xbf\xe6\x86K\xf91\x96\xc99\xe8F\x90i'I\x81T>+\xb0^\x86\x1dK\xda\x86"
        b'{\x04\xc3\x18D\xef\xdd\xd9\xbe\xfc\xc6\xae\xb5N\x9e5\xf5\xdc*\xf1;\x00\xd7\x00N\x86\xc8\x0c\x9c\xe5\x83Q0\x13:$F\xa6\xcb\xe5)\xc0\x98+5-\xef\xb5=VM[+\xb0\x0c\xadrX\x1f\x08"1\xa6\''
        b'\x02\x08]\xcb\x98\xc1l\x17\xd7\xf8X?\x87\xba\xe3\x9f\xd4\xe3Z\x0c\xfe\xf99\xea\xc9S,\xa3$A\xc24\xae\xe5\xedL!v\x9c{\xa2m\x8b\xda\xfb\x15\xa3\x02\xc3\x8c\xf7D\x13\xfcOfs,\xc3\x9e\xdf\xecG\xbc'
        b'\xfa\xe8\x87\x1bj\xc9\xcb\xd7j\x8b\xdd\xf1 7\x87\xfb\xac/AcT\xc95\xad/W.#D\x82\x84\xf9\xb9hK\xa1:.m\xd2y\xfe\x18\x84`m\xc8\xb5m2\xca\x01w\xfb\xd9\n\xa9\xf5\x92\xd1\x077_\xd4'
        b"\xc3E\x0c\xfe\xb7*\x9e\x06\xa3\x8b\xc6\x07\x045W\x05\x182\x17\x126Y\x9ai\x83\x9a\xcb\x06>\xd5\xef3\x8eC*]\xa6\x8d\xfa!'\xb84\x1e\x02\x93\xc8\xf7\xd8\xa5c\xb6\x01U \\\xd9\x95Hd\x1aj\xb4\xdc"
        b'~r4\x96x\x95w\x90\x80\xb8+\r\xb0\xda\x18a\xc3H\xa7c\x7f\xff\xf1\xc8N\x1d6R\x0b}\xd1\xe5#\xfe\x12\x11\xca\x9b\xa0L\x9e\xe2u\xef\xba<w\xcb+\xa6\xc8oG+1z\x12\x92\x17\xe9$\xed\x8as'
        b"\x8b`\x9d9\xfa\xd6\xec\xd3\x9d\x95-c\x84\xe0Aq\xbf_\xa2\x1a\x82'\x85b~H\xa2\xbe\xcc\x8b\xab\xb3\xe5\x91\xf9\x8a2{\x177\x07#\xa6\x16\xae\x17\xab^\x96\xc4sAK\xec\xa7\xc9\xdfE;o\xfe\xfe\xf4\xea"
        b'$\xb2\xe2\xab\xa2\'\xa3\xadO\xea\x1b\xe8\xfb\x9eM\xd4\x84auM\xe2\x17:"\xc7^\xa8\x19\x11DI1\xd4\x88\xf2LyX\x84\xf8\xb4\x94m\x989\xa7c\x06g\x98V\xa2\xb4\\\xc0\x9f\x8d\xc10\x86W\x1ev='
        b'y\xb3\xd3qK\xc2\xb2|\xc9\x06\x13r\xc3\xfb8SD~+f\xea<\xf2\xcb\x89\x16\xbd3\xb7 \x0b(\x9f\x80\x8a\xb9{A`\xe0+\xa8\x04\xb7\x11\xf8k\x1bB0\xe6\x06`\x1f]\xf9+i\x92\x13\x98\x19\x1a:'
        b'O\x85\xf4;\xd9r\xcd.\x08\xe2\x06\xc38\xd1O\x1a\xb0%\xfcd\xf1\xec)G\xd4\xc9\xe4\xdf?G\x9e\xd8f\rJ\x041\\{\xf5\xa0\x16>\x8b.Q\xcc\xa4\x1eS\xf8\x15-\xd0I1\x8eC3\x00s_&\x95'
        b'M\xcdh\xd2wx\xc9f\xea$L0U\xa8@\xf9\xf7T\x9b\x11\xdc~\xbe\x03\x81\x85\xca\xc6\xc5\x8f\x96\x0b\x1f\xc2\x04~\ry\xc1\x16\xad\x01x\xc1t\x10\x7f\x19\xe3\x94\x8f\xe3\xe7\x1f\x84\xf3\xcd\x81\x89\xe7#\xa8\xa2\xae'
        b'9\x10C\xc7L\xdf*\x91^/\x81\xea"\xa3T\xc7\xf0\x9e\xb0\xc2\x82\n\x10\x8dPe\xc4\xc2\xc4\x03z\x17\x08/\xa7~G/\x17zm\x12\xc0\xc7\xec\x80\xc4_\x9b\xe0\xabX\xa56\xb3\xbf\xd6?<\n\xe3_X\xa5'
        b"'\xc7Q\x1d\xe7\xe0F\xa6\xc7p\x8f\x1d\x1f\xf0\x8d2\x1b\xc8\x17\xde\x8c\x92\xeaS\xb7o|\xce\xf0\x8f\xe7>\xbb\xe7\xc44\xf4\xe35O\xe7\xce\x85Npr\xc0\x83\xb4\x0f\x0eb2\x15Tn\x9cy\xbb\xee\xc4w\x12\xda"
        b'\xd1\xd9_\xca^\xd7\x03\x9aahg2\xd5.\x19r\xd4\\re\xde\xd9\xfc\xca\xd0jA\x17j\xca\xf7\xa7b\xe9am,\x8d\xf1Ya\xe1d\xea"\xcfc\xfd\xba\xf3\x99D++\xc2]\xc6\xa3\xb6\x99\x9d\xa3\xc0\xdb'
        b"\x88\xa8\xab\xd6\xb6k\x18\x94W\x81gYx\xff\xd5F\x84\xcb\xd7\xd4\x0e;I\xb2\x8b!=\x7f\xe214X'M-\x11\xcb\xf6\xe2\xa1(\xd3iC\xe6\xc5\xce\x7f\xadh\xc8\xc5\xa7\xa1\x07\xe1t\xb4\xb3\x0e{\x0c\x80\x11"
        b'@\xa1\xbb\x90qZ\x89h\xff\xc1\x94\xc4\x02Q\xa8\xbd\x08\x07+\x8aA1|\x8ck.\x14\xd7\x0f\xc2~\x81\xc3\x8f\xda\x90\xf6\x82\xe4\xc6\xa5\xc3J\x01\xf8\x7f\xb2\xc2!\x90\x1b\xc9\xdb\x03\xbc?\x99y\x03\xaa\xda\xcf\xa6j'
        b'@\xeb \xbb\xa2\x99\x95;\x8eC4\x8c\xfdjC\x84\xdf\x82=Q)\xcd\xf27\xb9\xe9\rf\x05e\xd8\xe8\xb9\xfd\xfd\xe3\xbat\x82\xa6\xb5yQ \xab\xb7\x12\xd5\x87L8m-\xc3nVbM\x83$\x16\xc1\xb4s'
        b'\x1c,\x91"\xd9\xc8\x9c\x1f!\'\x13<\x96\x8e,0\x15\x83\xaftS\xca\xb3\xac\xfd)\xc8\xb6\xf3\x94\x8b\xe5\xa8\xcc\x96\xda\xcf\x9a\x84%\xbf\t?\x97i\x04:2\xc8\xcb\x0f\xf8y~a";\xb7\x1b(I\xdc8\x93'
        b'\xa0\xe3\x8b\x88\x86\xdb\xa4E\xce.\x97i%\xa7\x08\xfa\x85e\xbd,N\xa9\r\x82\xcc5\x18\xb8e\x8aF\xa3\xc7\x8d\x0fGe\xd5\xd9\xe8\xcb\xa0\xb16\xf8 \x8a\xd7\xb3\xd1\xe3#1\xfa\x9dx\xed\xd1\x11x\xab\xd1\r&'
        b'[h\xb1{\xcaV\xe8V\x83\xe3\x8f\xc7\x01@Z\xb6\xc3O\xd6\x85\x8c\xc4\xbbQ\xf9\x81;\x1e\xb7\xd4wA+e_\xc4\x12\x04h\xe7Tf-k|\xec<\x96l%\xb9\xbf\xbe\xa6\x95\xdc\xed\xc1\xc0lB8\xadL'
        b'\x06\x92-\xc8\xa5q\xf9\x95\xdd\x01Na1\xdf\x11-\x1f\xb8\xcd6\xe0W\xec,\xc9\x12\xf4B\xc7,t\x1c\xc1\xcb\x8b~\xa8i\xba\xe9\x16\xd5\x9a\x91\xa9\xe2j\x17\x9b+\n\x0bgv\x10l\xf2\x01?DA-\xde\xaa'
        b"\x1d\xfd\xb9\x16\xe3\x99\xd4Q\xbc\xf1&2\xf5+@q\xd5I\xb6\xc3x\xf8\x7f=\x1a\x02\xbeo\xce\xa6 v\xb8\x8f'n\xbd\x94\xe1~X\xb9\x03\xf4\x01#\xe1\x07\x81\xe7J\xb3\x1d\x9ePx\xa6\xb7L\x96<\xd1u\x9e"
        b'\x1c\x07\xbe\xf0\x15z\xca\x06\xe7\x17>\x0f\xc2\xd7x$\xbd\xa6z\xdb\x7f2\xbd\xaf\xb5\x85\x10;\xa5\xdb{M2"U\xa5\xd0\xe8D\\\x12\xf5\x8dL\xa5\xfb\xf8\x1c\xb2>j \xc9\x9e\xa3\r\x8ec)+g]5\x8c'
        b'\xe8\xf9\x8f\xbe\xdf<\x9f\x14G2\xfb_paKW\xe0D\x9a\xe2\xebVV\xb3r\xf1d\xb2X?\xd39\x05AE\xaeB\x05\xcc\xf1\t\xa0\xc5\x89\x85Si\x8c"B\xe1\xb3\xb5\x80\x83@F\xde\xb5\x05[\xf4\x98\x15'
        b'\x85\xc0\xb9`W\x89\x88\xb1\x8d\xf0\x97%c\xdd\x8bR\xb4\x1a\xd8\xd2\x1c\x975\x9f\xe7\xff\xe0\x05F3\xc7b\x9fGC\xad6Z\xcc\xf6\x83\xa6\x13S0#uv*\x8d\x1d\xf3?\xe1\xaa\xde\xdbeH\xf3S\xc5\x8e\xb8'
        b'\x9a\xac\xb4v\x19\xca\xc3E\xa5\x19\xd4\xddk\x89;Z\xfb{\xdf2\xf1\xd8p\xab7\x13\xbf\xb5P\xe7\xf6\xfb\x97\x18\xd277\x7f\x82\xc5]}\xf7\xefO\x18\x17s\xd5\x8b\x97:\xe5\xc0,Y\xa5%\xea\xc7\x99\xf4\xbf\xe4'
        b"\x92\x94`\xb2*\xdb\xba\x92\xa1y7i\xcc\x13iS3Bq\x1c\xf3x\x10\x92\x17p\x03&\xa90\x84\x9b\xfeZ\x1c\x8f%\xa0N\xf2x\\'\x1f\xef\xa7+\x8a\xcd\xf4\xa3\x8e\xa3\x03\t\r\xaaU\xc9\xf5t\x00R\xc2"
        b'R\xeb\x1a[\x96\x18\x07\xc2\x07)S~\xc7\xa4\x80\xf1\xc7\xfb\x9e_\x9cN\x13\xbaM#\x13K\x1fU\xadr\xbb\xf5\xbc\x84~\xb9\xb2\x15\xf8\x15P\x99\xdc\t\\\xe0\xb4\xa9\x80h=\x9bI\x91z\x85\xaa\xaf\x0e\x01I\xc0'
        b'wl;\x88bT\xa7\xb7V\xad\x86%\xa5\xa8\xf7-1\xb9\xb9q\x1b[\xa5\xa9PcS\xa4u\xf1\xca\x1d-\xb9\xd0\x11q\x10M\xa9i\xd4\xb3\\\xa6\xe1\x04\x84\xb2{\xb5<t@\xe2\xa9@\xf5|\xe6Z\x84\xf3\xa7'
        b'm@i\xc5\x1d\xb2\xbe\xe2h\xc8wc7\xec#\x83\xe4-\xb6\xde\xf2\xda\xc2\xa1\x7f\xe1\x8ax\xd0\xfdUp6\x0c~wm\x84\xf2s\xff\xa5Q\x1d7\x18\xad\x90\t(\xe0o\x80U\xd1\xf71\x92Q\x8b\xaf\x90g\xa3'
        b'}>]>=\xe6t\x92\xa6\xafe\x9c\xd63\x8d<,\xf5\x19\xb63\x8b\xf2\x8d\xc0\x19\xfd6yW\xfbd\xa0\xfaR\xe6h\x0b\xb9\x0cZ\xc2-]\xe8\xf3\xc34\xdf\x85\xa1@XP\x83j\x05J\x82\x8f\xdb3\x97\x9e'
        b'\x11W\xee\x1c\xf9\x07r\xf6\xf0\x11"\x85\x00l\x15)8\x8a\x8c\xea\xf3\x80+h\x7f\xf2\xd6\x9d\x92\x0f\x92\x8c\x98Q1\xc1\x8f\x0b\xac\x10\xc4\xd3\xd6\rJ\x8e\x1a\xf9|\x9eL\'T\\\xcd\xb7\xd019O\xa7\xad\xa5J'
        b'\x9e\xba\x0f\xad\xb4<\x0b\x8d^\x88/\xc9\x99\xd0\xd5^\xf7\xaa\x02;\xf2\xbd\xdeJ6\xc2\x94o\xa5\xc9\x95\xef\xb3\xec\xc3\xa8\xe9b\x95\xf1\xf7\xdf<WT|\x9b\xf2\xc1\xd0B\x8dQ\xa9/[\x0e\x1cn%+\xea\xf3\x8c'
        b'\xdf\xa4\xda\x8f\x80D\xf1\xc4P"K\xc6\xd8\xf0)y1 \xa1\xd5\x08\xe7\xb2N(\xff\xd4\xd9W\x0fy\xe2q\xd9\x8b\x05\x1c\xddd/J\xb71I\x87\xea\x85&]\xd1\'\xfe"/\xf2\xa2yLjk\xd3\x0f\x7f?'
        b'\x07\xe2N\x13y\x81-\r\x07\x98\x13\x00g\xf3\xdf\xf4\x7fklbO]\xd3ob\x18\xccq\xfe\x96I\x94\xd9 \x9d\xde4\xfd\xe0\xe0\x89\xcc.\xf0\xac9\xadv\x07s\x05\xe3\xbe\x08&\x9b\x8e>hD\x8eDQa'
        b'\x96\x11\x1f^a\xa9\x0f\xb8:\xbf\x95\x85\x00F\x0f\x81L\xdf\x0c\xd0\t\x8a\xb6\xc7\x1c4\xd4\x0eh\xf4\xe3\xe0\xablH\xce5%{B\xbe\xb0\xce\xbc\xc6B>(\xcc\xcf\xb7\xa1{\x8d\x1c1#\x11\x9d\xb3\xaf\x0b\x1bO'
        b'\xa9\xfd\x1c\xcb\xbb\xccD`\xfcb\xa7:xL\x9c\xe29\xf3\x89\xc8\xca\xc4\xcc\xb3!\x95\xaa\x07\x9e\xcf8\x94\x98\x16\x83\x9e\xa0\xe6\xd4\xff_yc\xa0\xb4*\xa7\xe8C\x80\xdc\xeb\xf3\x02\xe7@\x83tn\x0f\xcb\xaf,\xe7'
        b'S\x93\xa5uv^\x0c[Z;\xff\x06R\xff\xf8\xc5\xe0\x14\x11C\xca\xe4uw\x96e[\xfb\xbd\x8b\xf0\xa9\x19\xfd\xe1f\xa8\x84[\xbb\x04g8d\xe5fW\x1d\x83H\xff\x06\xbb}<\xa8di\x94\x85f\x8cI\xc3'
        b'M\xc0\xaff\x07\xe6\xc5\xed\xba\x9d\xeb\x93C\xc5\xf5\xfd\xe1\xf7{|3x\x15I\xcbQG\x87\xcf]\xbf|\xda\x1e\x9b\xb1m\xa1\x83\xb0%\x1bi\xf7\x16?\xf33\xea\x8fo\xa3\x11\xca\xdd\xcd\xc2y)\x8f\xa9\xf0$\xa3'
        b'k|\xf08T\xa2f\xdd.\xda\xfa\x1f\xa6\xa9\x10f\x08\xf0\xbb\x1a\xc9J\xad?\xc6\x06\x0bs_\xf7\x95\xfbYf\x1e\xb8\x15\xdb+\x1c\xb8 \x15|\x94\xe4\x88(\xd5Z\x0c\xf6\xacw\xbf0+\xa5\xc5.\xa7\xbc\xaa\xf2'
        b'\xc5\x01n8\xb5\x99\xa3\x85h\xd8\xa7n\\\xc1\xc4?DA&a`e,7\xb8\xae\xfdD*LN\x14sKH\x84\xe2\x07H\x1c\xae\xc95r\xd9\x02\x01\xda\x12j>\xb5\xf6#o\xb0$tT$>\x9d\xd4\xa6'
        b'\xb7\x1e\xa0Dm\nN\xb1i\x8c\xba\xd1^{:X\xfa7\x0c6\xb8\xcb\xd9\\|}=\tFg\xe0\xae\xd5\xae\xe3\x91AIY\x9a\\95Z\xe8\x05\x9f\x8a\xbf\x89\x9b\x83\xd8\x19\xe3\x90\xb4\xbaP\xb8\x8a{\xef\x82'
        b'\xdcu\xe8F\xacr-\x1d\xf8\x04\xb7$<\x1c|\x02?\xb9\xbbh\x8cp\xd3p\x81c\x015??\x99\xec\x1a\xb9K*\xc3\\X\xd8\x1a{j\xad\x13\xd535\xe7\x1f\xafL\x08\xe7&|)\xe0\xa5\xb1h\xa9`\x87'
        b'%$Z9\x9f\xdc.;\xab\xa1\xf5m\xed\xba\xd8P\x99\xc4\xde3\x8f\x9cy\x9d.\x16\x1c\xc9\x81l\xfd\x1e\xebh\xf0\x05|~\x13\x1a\x80\xb8\xd9 \x9f\x84TN@\xfa\x15>\xafRJ\xe4\x17\xe6\x8dJ\x16\xd1\xb1\x1c'
        b'\x93\x89\xad\x9d\x0br!w\x1d\xe6\x99\\v\xde\x19 \xafC\x12\x7f\x13IM\x86#\xdc\xf6\xfe\xdf<3\xa4\xf0\x0fR\xfc\xd0({\xd7\xca!\xb1\xbd\xe6c1\xa3O\x84\xee*\xcf\x87\xe4Xf%oY\xb5p\x1dg'
        b'\xe8\x95>R\x04\x90\xbaz\x80E\xcc$\xfd\xc0B?\x15}n\x83A\x82U\x1a\xabH\xf9\xea\xfc_p\xf0\xc7<0Ug\x07\x18;\xbe\xa7\x83\x84$\xc5\x0b\xa5\xc5V \xeb\xdb\xf5*\xd7\xcc\xaf\x8a\xbf\xf1\x90\x13\xd9'
        b"9E\x01\xa9=\x11\xcf\x93\xb5\x01\x00\xc7\x15\xba\xfb\x94\x1a\xb8\x00\xb5`\xd9j\xe9*\x0e.\xbf\\\xae$X\x1c\xb1\xd6\x976d\x9d\x9d\x02s\xaa(\x15\xc9\x14Za\xa7\x16\x18\x06\xf2\xce\x9cD\x8d'\x1be\x9b4'"
        b'At\x8aI/\x1f>Bk\x83\x9e\xb8\xad\x8e\xf8d\xc8\xa7\x1e\x1b3x4n\xed\x1b{\xbf_\x9e\xb2\x17h\xd1\x04qT:\x88<\xbe\xc9\x90\xc5r\xc3X]\xc7BP\x9f\x06R\x8e:\x7f3eD\xc5\xb2\xf8w'
        b'p\x18]\x8aN\xe6o\x04#\xcb\x99\x1a\x16u>\xf9\x04\xd1e\x1a9/;\xb4\x14o\x96\xaeK\x8dsp\xb6\xcb\xd5r\x00\xc6\x1ax\xba\xcb\x9c\xf7l8\xd8\x9d\x176\x91\xdd\x0f\xbav\x8fUM)\xe5\xb9@~\x99'
        b'F\x15ztP\xc77\xacO\xdb\xd3?\xd0\x02\xff)\xd6\xcdX\xc5\x00Nj\xe78>\x83S\x10\x9d\xe7\x89f\xba\x07c\xec\xaf\xa3\xa5\x95\x8e\x93e\x15\x92\x8fq\x1a\x04\x13\x87u\xe9\x1f\x1dA\xfc\xdd\xd2\xa6\x175.'
        b"\x03\x14;\xd6\xd4'\xd6\x1c\xdb\xed\x92*\x80x\x1a\xb7\xc9\xa5\x16\xa2\xefj\xc9\xfc\x93y\\6\x1f>v`GY\xd9\x13m\x83\xfd34\xb6^\\\x08\xaeu\xa2_D\xfbh\x08\xd8\xa2{c\x0f\x04\xb1\x01\xa6\xc7\x14"
        b'\xf9\x1e\x8cWlf\x87\xf2\xb7\xcd\xafW\x90~R\xef\xef \x9c6\x95j\xf2\x1b\x05\xfd\xda\x13\xfbS,\x8dkz\xfa|\x8e\xd1\xba\xfe\\&}\xcf\xd9tQU\x1e\xab\xe1g\xe6\xe3\x84\x8aZ\xac\x7f\x82.\xfd5\x19'
        b'V:\xc2~\x1a/\xdb\xff@\xd8\x9dT\xdfA\xa8\x10\xf1\x12`\x81.\xb4k\xa1\x8f\xb7\x88M\x08\x94C8/\xf3I\xe1\xb5:i\xecO\xe8\x89\xcf\x06\xb0#\x0f,\xf26e\xb3!NfRN\xfc\x7f\xcd\xf3<\xef'
        b'\xedc<\xc3hgI\xbcR\x8c\x7f\x05EtV\x9d>5_c\x84Z[\xe8c\xc0\xc5\x98\xc4:\x0fElW\x99l\xb5V\xa4\xba\x17\xe6Y\xb9\xaa\x19\x87\x9d\xedf\x9f9\xd2\xb8P\x88\xc4%e\rv2\xa9\xe4'
        b'[xi\xc4T\xe2w\xe3\xaf\x96\xb0\xaavf\xd5)(\x0f1^\x8e\xcc\xe9Up)\xb6\xd5n\x94\rY\x86IuGJ"9U\xed\x95\xd3NV\x0c\xdd-\xeeL>+\x02D\x96\xf3g\x83+\x01\x119\xa1"'
        b'WK/\x1c\xc8\xa6\x97\x8b\xc6S}\xb3\x9ak6\xde0\x14\x85N\xefq&;\xabZ\x9e\x92\x82\xef\t\xa5\x8cKR\x11\xf2|F\xc2\rO\xbbez7\xaf\xc6)\xd5-u\xa9\xcc\xa1\xbc%\x95\x87\xcc\xe2\xaa\xee\x1a'
        b'\x89\x89\xaa%\xd5\t\x80<)gN\xcc\xd5\xeatf\xf0\xcb\xda$\xf9\xaa\xf4A\x89rN\xe5\xb4\xc9\xf5\xfb0,\x98e\x8ee`\xd0\xaf\x0eX\xdaUX0<\x04B\xfe\xac!\xdc\x84\xf9M\x1e\xa6\x99\xc9\xb2\x14\xc8'
        b'\xab7-\x94\xe7C\x07\xad\x8b\xc0\x8c\xdav\xdbH\x8a[\x80\xdcpH-\r\x9eo\xea\xc02\xb0y?@\xdek\xad\x7f\xc7\xa0\xcdpv\x0f\xf8\x8d^\xb4 +\xc9\xd5\xfb\xd7\x03%(\xd3\x1e\xa5\x1b\xa7\x1a\xd9j\xd9'
        b'\x1a\xba\xb0vEt\xe3\x07\xd64\x1f\x12\xd1\xcea\xf5\x94\xe3g@\x7f\xbbN?\xf7#\xeew\x8b\xf8\xd80;$\x8b\xbaV\xdb^9\x8c}d\xe9x\xb2\xa8\xe0t\t\xfd\\\x1b\xc9\xb6\x8b \xe6\x9fw\x11\xec\x9a\xad'
        b'\r\x19\xe5a\xfd\x18\xad\xdf\xffk%\x1e\xc0?\xfa\xa8\x81i-\xee\xbe63\xa9\x00\xfeZ\xa5\x99\xd4\t\xcb\xdf\x1d\xbf\xc5\xac7\x12\x18`\x12\x97\xe3\xca\x00H\xf9p\xf1\x7f\x8a\x83\x07\x07\xab[\xfdX\xf7a\x174m'
        b"h\x01\xebQ*3XG\xf4\xfa:4\xfd\xa9Z\n\xd9\xc0y\xd1\xb45|:}\x8a\xd7\x8c\x0b\x7f\x19\x97F\xa9\xf6\xc6\x81\x0f\xd5\xa6\x90\xb7\x8c\xed\x9a\xf9*\xfb'\xa3\xb9\xdc\xcdc\xfb\xd9a\xe1\xad\xd2\xf0\x14\xb9\xe6"
        b"}2\xe0\xd7\xa7\xc9\xb7|\xd0J\x0f\xb8\xc4tps\x8f\xfd4\xc7\xf3\xe3\x81\xaa\xe5\xf8\xe9\x14'\x7f\x12*\xf7%\n\xbd\xf5\x95\xa5y\xfd\xae\x95\x1b\xf2G\xf2^\xa4qj\xf1&3d/\x0f\x1e\xa4=\xaa\xa5J\xea"
        b'f@n\x7f\xe4\x00\\y\x16=\xde\xc2\x0f\xfb>\xcaPs\xed*,\xf0__\x0b\x99;`On\xad\x81\xcb\x97v\x8f)\x9a\x93\xde#\x9c\xf0J`\x1c\x89s\xcb\x06A6\xae\xd7\xf3\xb0\xd4\xa5\x89*\x8a \xdb\x94'
        b'J\xb4?\xf4\x0b\x8a\x8c,\xed\xeaR\xa5,\\YR\xc7\x0b\x9f\xf1\xde\x8c\xaf\x98|\x05]\x8dJ\xf3\n/w\xaf\xce\n\xe6\x1f\xc0\xe1\x0b\xee\xe1/v\xd1I\xc1W\xa4\xc8\x00W\x9e\xdc\xa7\xbe\x14.\x9a\x0e\xbd\xaa\x16'
        b'\x8ad\xf2\x0f\xaf\x1d\xb9\xf1\xa0r\xbd\xa3^\xeb\xc8u\xa2S4\xad\xb1\xe0\x96\xd4c\xdf\x0fP\xdf:\x90\xf5*b^5G\x19\xa9Z\xc7UA\xcf\xe5\xa3\xc8n\xa9Q\xc7\xc5<X\xed\xce\xe2\x9c\xbavQ\xb6\xea\x04'
        b'Jb\xa8P\xbb\xec\x06\xdf\x07\xa6\xbf"%{\xe6\xc5}\xc4vg\x94\xfd\xc1\xc8\x01\xbe\x12\xf0\xf3#\x94\x0eP\x97\x18\x99\x9cFex\xb9\x1d\xcf\x1d\x82w\x13i\xd0\xe7f\xa0\x96\xfe~ \xaf\xcc\xc8\x07\xad&\x12C'
        b'8\xe1\xc7\rK\xa4\x9cY\x97\x99y\xab\xe1\x11\x94a\xacI\xe3\xd4\x7f\x1fja\x0b;0\x8c\xba+\xb7\xb9(W\xeeB\x88#4\x9f\x1b\xa2\xa0n%< \x9d\xd1h\xffOc\x90\xbd\xde\xc4B\x95\xdb\xc4Y\xcb\xd2'
        b'\xb3\xb2\xbc\x83\xf4\xce]\x98\xb3\x10\x17TR }#_sC\xe54\xf8\xcf\xfd\xa5k\x8e\xef\xe8\xa0\x9c\xf0\x94VK\x8c \x1f\xf0\xb7@\xf5\xf8\xe7g"\xe9,@DB\x85\xd4\t\xcbfD\x0c\xdb\x0b^\x93+\x1c'
        b"\x16\x0c\xa6\xed<$&I\xaf\xe1\x03\x94'\xa6I@\xb5\x16\x9a/u}\x0cZ(\x9a\x11R1#\xd5\xb6\x8cX\xd6\xe1\xf8\xadMF\xc1\xd4;\xd6\xea\xea.\xf8\xde\\\x17\xb8\xbdS\xf6\xb3\x0e\x1d\xa2\x97Q\xfcQ\xd5"
        b'\xeex\xc0\xcf\xc6\x93\t4Q\x86\xcbl#\xa0\x0bG\x94\x8b\x08j\xa1\x08\x13B\xda\xb5\xc6\x1c\xaa\xa0"\x17MN{hrF\x94\xe9\xae\xc9\x8f\xe9\xdfW\x8c=\xf5\xd5\xb8\xcdYVp\xebP\xf8\x1d\xb8r\xe6\xce\xe8'
        b'\xc0Duj\xfb_E\n\xc4\xa5\xedy\xa0\x00\x7f.w\x00\xda\xfb\xa4\xde \xde\x92\x18\x89o\x03\xed5\xbel\x05\xb4\xc1\xb2\x96l\x17J\x9b\xa9T\xeaPH\x14\x8b\x896~=\xf8\x0b\xb8ijX\x84\xe5s\xf4\xd8'
        b'\x94r\xd5\xca\xd4_Y\xa9\x95<_\xd5\xcb\x0e^:\xea\xaf\x15\x19\x86\xdcK\x9fks?\xc8\xa3\xdc\xbcP;\xf9\x88\xb2\x8c\x10s)P\x96\xb7t\x02\xbcI\x9f]\xc8\xfe\x1a\x04f\xdd\xf2\x936\x02\xd5\xee\xc83\xca'
        b'\xa42R\x84\xf4\xf5\xc0\xb6Z\xed\x8d\xba\xf2\xfe%\x10\xbe\x9dP\xad@\xb1\xc2\rO\xdfE\x06\xda\x11,\xf8\xa1\x8d(N"\x7f\xd0\xf6\xab\x89oM\xb5\xa0\t\xd2\xd3\xb3\x90\x15\x1bXG\xc3\xac\x7fv\x99.mZI'
        b"\x8et4 aK\x03\xaf\x05\xbe\x8c\x90\xea\x9c\xbcR4i\x9e\x88\xe4A\xb0fT\xf8\xe5\x86\x1e\xeb>\xc5\x14\x89\xa7V\xb8\x03g\xc8\xbc\xe4-B\xf0\xc3\\5\x1c\xfc'\xd2z\x9f\x1d\xf7\xafX\r\xa1\x99\xa2\xf2\xd7"
        b'\xe9G}Q\xf8\xfc*\x1d/\xe6\x9d\xe0\x93\x950\xef\x16\xef\n\xce\xf2\xffg\xb4\xc26H\xf4\xd2\xa8V\xe4\xf4\xda\xc86\nS\xce3j{\xdfl\xe2\x02\xd7ig\x9a\xaf\xab\x7f\xb0\x107\x17\xa3\x00\x80\xc8\xc3\x89\xe6'
        b'\xfe\xe0\xdb\xd4\xb2\x86\x14\xa8V\xaf\xc8\xbfP\xde\xa4\xfb\xb4.\xb6\xdf0\x19@\xcfp{\x8e\x0be#y[\xbe:\xf234\x82o\\,\xee\xc5\x8b\x18:F]/&\x9d#\xd9\x032\xfduX\x82`\xc8\x06\x8f_'
        b'\xe5\\\xf1\xaeP|d\xb7\xaaR\xe5\xaa:Ef\xea\r\xa8\xdcv\xb6v\xbf\xf4V\xdf\xc9\x87\xea`\xdd\xea\x1aE\xd1\x98\x9dW\xe2:bT\xda\xe4\xcc\xdd\xe1E\x19\x15\x9d\xef\xf3\xffz]&nh\xcc\x90\x0fA\xd6'
        b'\xd9\x88\x10\xbc\x0c\x17\x9c\x88\'}\x11El\xb8\xf6\xe8\x85\x88\xc8"\xb6\xf6\xb4\xde\xbe\xbe\xf8\xdc\xbf\x00l\x81YD\x85\xa8\x05\x12\x917\x8a\xf5\x9ea\xb7\xad\xf8\xff!\xc5Qce\xdfG}\x17\x9f\x04l\x91\xdf\xb4\xa9'
        b'&\xfc\x10\x99F\x10\xaat\x8f\\\\\x91\xeb\xb5\xfbb\xa19\x80\x8b\xde\x86\xb2\xcf\xd7J\x023B\x89\xbfB\x0f7u\xc1h\xac\x1a\xbc\xfb\xe6\xc7n_\xe1\xdc\xe6u\x7f\xa6\xf5\x84\xd8a\xe7\xd0\x93\xa5)\x8a\xe1\xd4M'
        b'\x87\xb4z\xb2g`\x99\x90\\k2\x93\xddS}\x1ed\xeb[`\xec\xb8s[\xe6\x07~\xf2\xddTX\xd1\xdf\x15\xb6\xd2\x19F\xba\xd5\xa9\x8dq\x1e\x9b5(|\x8dc27\x85\xea\xa5\x15=\xd8\xa5\xb7@\x7fA\xb7'
        b'\xbb\x9a\x9e\x01l\xe9\nx\xf0\xcb\'\x91\xbb\xd9M\xce\x19\xbb\tsM\xfb.s\xebt\xe0)7\xcf\x0b\xd2!\xfc\x82\xbc\xe2\xa0\x857\x1au+\x89"\x0eom\xf8\xaf\xa8\xbc\x9aN\x86?\xca\xc50u\x04W\xb3\x18'
        b'#\xd2a\xd5\xb5\xbdj\xccnPF^fM\xc6\xe5pn\x01\xdcC\xdc\xc7\xd8\x10\xa5\x91\n\xa5\xbf\x16O\xd8o\xca\x83\xd6s3^\xf1\xdf3\x00\xe5\xbbTd\xca\x89\x1eB\x87%@\xf0D\xa9\x12\xca\x98CKd'
        b'\x1f7\x06\xf8\xb6\x1d\x85\xa0\xcf\x86\xe1>\xde\xbd\x8cJ \xd7\x183\x918\x85\x03\x1d\x060\x9a|\xcd`dH\xefk\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntim'
        b'eError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x16<frozen fintech.swift>\xda\x08'
        b'<module>\x01\x00\x00\x00s\x04\x00\x00\x00\n\x01\x14\x01'
    ))
